# yandex-api-client
API Яндекс Маркета помогает продавцам автоматизировать и упростить работу с маркетплейсом.

В числе возможностей интеграции:

* управление каталогом товаров и витриной,

* обработка заказов,

* изменение настроек магазина,

* получение отчетов.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: LATEST
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import yandex_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import yandex_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import yandex_api_client
from yandex_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.partner.market.yandex.ru
# See configuration.py for a list of all supported configuration parameters.
configuration = yandex_api_client.Configuration(
    host = "https://api.partner.market.yandex.ru"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with yandex_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = yandex_api_client.BidsApi(api_client)
    business_id = 56 # int | Идентификатор кабинета. Чтобы узнать идентификатор, воспользуйтесь запросом [GET campaigns](../../reference/campaigns/getCampaigns.md#businessdto).  ℹ️ [Что такое кабинет и магазин на Маркете](https://yandex.ru/support/marketplace/account/introduction.html) 
    page_token = 'eyBuZXh0SWQ6IDIzNDIgfQ==' # str | Идентификатор страницы c результатами.  Если параметр не указан, возвращается самая старая страница.  Рекомендуется передавать значение выходного параметра `nextPageToken`, полученное при последнем запросе.  Если задан `page_token`, параметры `offset`, `page_number` и `page_size` игнорируются.  (optional)
    limit = 20 # int | Количество товаров на одной странице.  (optional)
    get_bids_info_request = yandex_api_client.GetBidsInfoRequest() # GetBidsInfoRequest | description (optional)

    try:
        # Информация об установленных ставках
        api_response = api_instance.get_bids_info_for_business(business_id, page_token=page_token, limit=limit, get_bids_info_request=get_bids_info_request)
        print("The response of BidsApi->get_bids_info_for_business:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BidsApi->get_bids_info_for_business: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.partner.market.yandex.ru*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BidsApi* | [**get_bids_info_for_business**](docs/BidsApi.md#get_bids_info_for_business) | **POST** /businesses/{businessId}/bids/info | Информация об установленных ставках
*BidsApi* | [**get_bids_recommendations**](docs/BidsApi.md#get_bids_recommendations) | **POST** /businesses/{businessId}/bids/recommendations | Рекомендованные ставки для заданных товаров
*BidsApi* | [**put_bids_for_business**](docs/BidsApi.md#put_bids_for_business) | **PUT** /businesses/{businessId}/bids | Включение буста продаж и установка ставок
*BidsApi* | [**put_bids_for_campaign**](docs/BidsApi.md#put_bids_for_campaign) | **PUT** /campaigns/{campaignId}/bids | Включение буста продаж и установка ставок для магазина
*BusinessOfferMappingsApi* | [**add_offers_to_archive**](docs/BusinessOfferMappingsApi.md#add_offers_to_archive) | **POST** /businesses/{businessId}/offer-mappings/archive | Добавление товаров в архив
*BusinessOfferMappingsApi* | [**delete_offers**](docs/BusinessOfferMappingsApi.md#delete_offers) | **POST** /businesses/{businessId}/offer-mappings/delete | Удаление товаров из каталога
*BusinessOfferMappingsApi* | [**delete_offers_from_archive**](docs/BusinessOfferMappingsApi.md#delete_offers_from_archive) | **POST** /businesses/{businessId}/offer-mappings/unarchive | Восстановление товаров из архива
*BusinessOfferMappingsApi* | [**get_offer_mappings**](docs/BusinessOfferMappingsApi.md#get_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings | Информация о товарах в каталоге
*BusinessOfferMappingsApi* | [**get_suggested_offer_mappings**](docs/BusinessOfferMappingsApi.md#get_suggested_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/suggestions | Предварительный просмотр карточек на Маркете, соответствующих вашим товарам
*BusinessOfferMappingsApi* | [**update_offer_mappings**](docs/BusinessOfferMappingsApi.md#update_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/update | Добавление товаров в каталог и редактирование информации о них
*CampaignsApi* | [**get_campaign**](docs/CampaignsApi.md#get_campaign) | **GET** /campaigns/{campaignId} | Информация о магазине
*CampaignsApi* | [**get_campaign_logins**](docs/CampaignsApi.md#get_campaign_logins) | **GET** /campaigns/{campaignId}/logins | Логины, связанные с магазином
*CampaignsApi* | [**get_campaign_region**](docs/CampaignsApi.md#get_campaign_region) | **GET** /campaigns/{campaignId}/region | Регион магазина
*CampaignsApi* | [**get_campaign_settings**](docs/CampaignsApi.md#get_campaign_settings) | **GET** /campaigns/{campaignId}/settings | Настройки магазина
*CampaignsApi* | [**get_campaigns**](docs/CampaignsApi.md#get_campaigns) | **GET** /campaigns | Магазины пользователя
*CampaignsApi* | [**get_campaigns_by_login**](docs/CampaignsApi.md#get_campaigns_by_login) | **GET** /campaigns/by_login/{login} | Магазины, доступные логину
*CategoriesApi* | [**get_categories_tree**](docs/CategoriesApi.md#get_categories_tree) | **POST** /categories/tree | Дерево категорий
*ChatsApi* | [**create_chat**](docs/ChatsApi.md#create_chat) | **POST** /businesses/{businessId}/chats/new | Создание нового чата с покупателем
*ChatsApi* | [**get_chat_history**](docs/ChatsApi.md#get_chat_history) | **POST** /businesses/{businessId}/chats/history | Получение истории сообщений в чате
*ChatsApi* | [**get_chats**](docs/ChatsApi.md#get_chats) | **POST** /businesses/{businessId}/chats | Получение доступных чатов
*ChatsApi* | [**send_file_to_chat**](docs/ChatsApi.md#send_file_to_chat) | **POST** /businesses/{businessId}/chats/file/send | Отправка файла в чат
*ChatsApi* | [**send_message_to_chat**](docs/ChatsApi.md#send_message_to_chat) | **POST** /businesses/{businessId}/chats/message | Отправка сообщения в чат
*ContentApi* | [**get_category_content_parameters**](docs/ContentApi.md#get_category_content_parameters) | **POST** /category/{categoryId}/parameters | Списки характеристик товаров по категориям
*ContentApi* | [**get_offer_cards_content_status**](docs/ContentApi.md#get_offer_cards_content_status) | **POST** /businesses/{businessId}/offer-cards | Получение информации о заполненности карточек
*ContentApi* | [**update_offer_content**](docs/ContentApi.md#update_offer_content) | **POST** /businesses/{businessId}/offer-cards/update | Редактирование категорийных характеристик товара
*DbsApi* | [**accept_order_cancellation**](docs/DbsApi.md#accept_order_cancellation) | **PUT** /campaigns/{campaignId}/orders/{orderId}/cancellation/accept | Отмена заказа покупателем (DBS)
*DbsApi* | [**add_hidden_offers**](docs/DbsApi.md#add_hidden_offers) | **POST** /campaigns/{campaignId}/hidden-offers | Скрытие товаров и настройки скрытия
*DbsApi* | [**add_offers_to_archive**](docs/DbsApi.md#add_offers_to_archive) | **POST** /businesses/{businessId}/offer-mappings/archive | Добавление товаров в архив
*DbsApi* | [**calculate_tariffs**](docs/DbsApi.md#calculate_tariffs) | **POST** /tariffs/calculate | Калькулятор стоимости услуг
*DbsApi* | [**confirm_business_prices**](docs/DbsApi.md#confirm_business_prices) | **POST** /businesses/{businessId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (основная цена)
*DbsApi* | [**confirm_campaign_prices**](docs/DbsApi.md#confirm_campaign_prices) | **POST** /campaigns/{campaignId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (цена в магазине)
*DbsApi* | [**create_chat**](docs/DbsApi.md#create_chat) | **POST** /businesses/{businessId}/chats/new | Создание нового чата с покупателем
*DbsApi* | [**create_outlet**](docs/DbsApi.md#create_outlet) | **POST** /campaigns/{campaignId}/outlets | Создание точки продаж
*DbsApi* | [**delete_campaign_offers**](docs/DbsApi.md#delete_campaign_offers) | **POST** /campaigns/{campaignId}/offers/delete | Удаление товаров из ассортимента магазина
*DbsApi* | [**delete_hidden_offers**](docs/DbsApi.md#delete_hidden_offers) | **DELETE** /campaigns/{campaignId}/hidden-offers | Возобновление показа товаров
*DbsApi* | [**delete_offers**](docs/DbsApi.md#delete_offers) | **POST** /businesses/{businessId}/offer-mappings/delete | Удаление товаров из каталога
*DbsApi* | [**delete_offers_from_archive**](docs/DbsApi.md#delete_offers_from_archive) | **POST** /businesses/{businessId}/offer-mappings/unarchive | Восстановление товаров из архива
*DbsApi* | [**delete_outlet**](docs/DbsApi.md#delete_outlet) | **DELETE** /campaigns/{campaignId}/outlets/{outletId} | Удаление точки продаж
*DbsApi* | [**delete_outlet_licenses**](docs/DbsApi.md#delete_outlet_licenses) | **DELETE** /campaigns/{campaignId}/outlets/licenses | Удаление лицензий для точек продаж
*DbsApi* | [**generate_boost_consolidated_report**](docs/DbsApi.md#generate_boost_consolidated_report) | **POST** /reports/boost-consolidated/generate | Отчет по бусту продаж
*DbsApi* | [**generate_goods_realization_report**](docs/DbsApi.md#generate_goods_realization_report) | **POST** /reports/goods-realization/generate | Отчет по реализации
*DbsApi* | [**generate_order_label**](docs/DbsApi.md#generate_order_label) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes/{boxId}/label | Ярлык‑наклейка для коробки в заказе
*DbsApi* | [**generate_order_labels**](docs/DbsApi.md#generate_order_labels) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels | Ярлыки‑наклейки на все грузовые места в заказе
*DbsApi* | [**generate_prices_report**](docs/DbsApi.md#generate_prices_report) | **POST** /reports/prices/generate | Отчет «Цены на рынке»
*DbsApi* | [**generate_shows_sales_report**](docs/DbsApi.md#generate_shows_sales_report) | **POST** /reports/shows-sales/generate | Отчет «Аналитика продаж»
*DbsApi* | [**generate_stocks_on_warehouses_report**](docs/DbsApi.md#generate_stocks_on_warehouses_report) | **POST** /reports/stocks-on-warehouses/generate | Отчет по остаткам на складах
*DbsApi* | [**generate_united_marketplace_services_report**](docs/DbsApi.md#generate_united_marketplace_services_report) | **POST** /reports/united-marketplace-services/generate | Отчет по стоимости услуг
*DbsApi* | [**generate_united_netting_report**](docs/DbsApi.md#generate_united_netting_report) | **POST** /reports/united-netting/generate | Отчет по платежам
*DbsApi* | [**generate_united_orders_report**](docs/DbsApi.md#generate_united_orders_report) | **POST** /reports/united-orders/generate | Отчет по заказам
*DbsApi* | [**get_all_offers**](docs/DbsApi.md#get_all_offers) | **GET** /campaigns/{campaignId}/offers/all | Все предложения магазина
*DbsApi* | [**get_bids_info_for_business**](docs/DbsApi.md#get_bids_info_for_business) | **POST** /businesses/{businessId}/bids/info | Информация об установленных ставках
*DbsApi* | [**get_bids_recommendations**](docs/DbsApi.md#get_bids_recommendations) | **POST** /businesses/{businessId}/bids/recommendations | Рекомендованные ставки для заданных товаров
*DbsApi* | [**get_business_quarantine_offers**](docs/DbsApi.md#get_business_quarantine_offers) | **POST** /businesses/{businessId}/price-quarantine | Список товаров, находящихся в карантине (основная цена)
*DbsApi* | [**get_campaign**](docs/DbsApi.md#get_campaign) | **GET** /campaigns/{campaignId} | Информация о магазине
*DbsApi* | [**get_campaign_feed_categories**](docs/DbsApi.md#get_campaign_feed_categories) | **GET** /campaigns/{campaignId}/feeds/categories | Категории магазина
*DbsApi* | [**get_campaign_logins**](docs/DbsApi.md#get_campaign_logins) | **GET** /campaigns/{campaignId}/logins | Логины, связанные с магазином
*DbsApi* | [**get_campaign_offers**](docs/DbsApi.md#get_campaign_offers) | **POST** /campaigns/{campaignId}/offers | Список товаров, размещенных в заданном магазине, с параметрами размещения
*DbsApi* | [**get_campaign_quarantine_offers**](docs/DbsApi.md#get_campaign_quarantine_offers) | **POST** /campaigns/{campaignId}/price-quarantine | Список товаров, находящихся в карантине (цена в магазине)
*DbsApi* | [**get_campaign_region**](docs/DbsApi.md#get_campaign_region) | **GET** /campaigns/{campaignId}/region | Регион магазина
*DbsApi* | [**get_campaign_settings**](docs/DbsApi.md#get_campaign_settings) | **GET** /campaigns/{campaignId}/settings | Настройки магазина
*DbsApi* | [**get_campaigns**](docs/DbsApi.md#get_campaigns) | **GET** /campaigns | Магазины пользователя
*DbsApi* | [**get_campaigns_by_login**](docs/DbsApi.md#get_campaigns_by_login) | **GET** /campaigns/by_login/{login} | Магазины, доступные логину
*DbsApi* | [**get_categories_tree**](docs/DbsApi.md#get_categories_tree) | **POST** /categories/tree | Дерево категорий
*DbsApi* | [**get_category_content_parameters**](docs/DbsApi.md#get_category_content_parameters) | **POST** /category/{categoryId}/parameters | Списки характеристик товаров по категориям
*DbsApi* | [**get_chat_history**](docs/DbsApi.md#get_chat_history) | **POST** /businesses/{businessId}/chats/history | Получение истории сообщений в чате
*DbsApi* | [**get_chats**](docs/DbsApi.md#get_chats) | **POST** /businesses/{businessId}/chats | Получение доступных чатов
*DbsApi* | [**get_delivery_services**](docs/DbsApi.md#get_delivery_services) | **GET** /delivery/services | Справочник служб доставки
*DbsApi* | [**get_feed**](docs/DbsApi.md#get_feed) | **GET** /campaigns/{campaignId}/feeds/{feedId} | Информация о прайс-листе
*DbsApi* | [**get_feed_categories**](docs/DbsApi.md#get_feed_categories) | **GET** /campaigns/{campaignId}/feeds/{feedId}/categories | Категории прайс-листа
*DbsApi* | [**get_feed_index_logs**](docs/DbsApi.md#get_feed_index_logs) | **GET** /campaigns/{campaignId}/feeds/{feedId}/index-logs | Отчет по индексации прайс-листа
*DbsApi* | [**get_feedback_and_comment_updates**](docs/DbsApi.md#get_feedback_and_comment_updates) | **GET** /campaigns/{campaignId}/feedback/updates | Новые и обновленные отзывы о магазине
*DbsApi* | [**get_feeds**](docs/DbsApi.md#get_feeds) | **GET** /campaigns/{campaignId}/feeds | Список прайс-листов магазина
*DbsApi* | [**get_goods_stats**](docs/DbsApi.md#get_goods_stats) | **POST** /campaigns/{campaignId}/stats/skus | Отчет по товарам
*DbsApi* | [**get_hidden_offers**](docs/DbsApi.md#get_hidden_offers) | **GET** /campaigns/{campaignId}/hidden-offers | Информация о скрытых вами товарах
*DbsApi* | [**get_model**](docs/DbsApi.md#get_model) | **GET** /models/{modelId} | Информация о модели
*DbsApi* | [**get_model_offers**](docs/DbsApi.md#get_model_offers) | **GET** /models/{modelId}/offers | Список предложений для модели
*DbsApi* | [**get_models**](docs/DbsApi.md#get_models) | **POST** /models | Информация о нескольких моделях
*DbsApi* | [**get_models_offers**](docs/DbsApi.md#get_models_offers) | **POST** /models/offers | Список предложений для нескольких моделей
*DbsApi* | [**get_offer_cards_content_status**](docs/DbsApi.md#get_offer_cards_content_status) | **POST** /businesses/{businessId}/offer-cards | Получение информации о заполненности карточек
*DbsApi* | [**get_offer_mappings**](docs/DbsApi.md#get_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings | Информация о товарах в каталоге
*DbsApi* | [**get_offer_recommendations**](docs/DbsApi.md#get_offer_recommendations) | **POST** /businesses/{businessId}/offers/recommendations | Рекомендации Маркета, касающиеся цен
*DbsApi* | [**get_offers**](docs/DbsApi.md#get_offers) | **GET** /campaigns/{campaignId}/offers | Предложения магазина
*DbsApi* | [**get_order**](docs/DbsApi.md#get_order) | **GET** /campaigns/{campaignId}/orders/{orderId} | Информация о заказе
*DbsApi* | [**get_order_buyer_info**](docs/DbsApi.md#get_order_buyer_info) | **GET** /campaigns/{campaignId}/orders/{orderId}/buyer | Информация о покупателе — физическом лице (DBS)
*DbsApi* | [**get_orders**](docs/DbsApi.md#get_orders) | **GET** /campaigns/{campaignId}/orders | Информация о заказах
*DbsApi* | [**get_orders_stats**](docs/DbsApi.md#get_orders_stats) | **POST** /campaigns/{campaignId}/stats/orders | Детальная информация по заказам
*DbsApi* | [**get_outlet**](docs/DbsApi.md#get_outlet) | **GET** /campaigns/{campaignId}/outlets/{outletId} | Информация о точке продаж
*DbsApi* | [**get_outlet_licenses**](docs/DbsApi.md#get_outlet_licenses) | **GET** /campaigns/{campaignId}/outlets/licenses | Информация о лицензиях для точек продаж
*DbsApi* | [**get_outlets**](docs/DbsApi.md#get_outlets) | **GET** /campaigns/{campaignId}/outlets | Информация о точках продаж
*DbsApi* | [**get_prices**](docs/DbsApi.md#get_prices) | **GET** /campaigns/{campaignId}/offer-prices | Список цен
*DbsApi* | [**get_prices_by_offer_ids**](docs/DbsApi.md#get_prices_by_offer_ids) | **POST** /campaigns/{campaignId}/offer-prices | Просмотр установленных в магазине цен
*DbsApi* | [**get_report_info**](docs/DbsApi.md#get_report_info) | **GET** /reports/info/{reportId} | Статус генерации и скачивание готовых отчетов
*DbsApi* | [**get_return**](docs/DbsApi.md#get_return) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId} | Информация о возврате или невыкупе
*DbsApi* | [**get_return_application**](docs/DbsApi.md#get_return_application) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/application | Получение заявления на возврат
*DbsApi* | [**get_return_photo**](docs/DbsApi.md#get_return_photo) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/{itemId}/image/{imageHash} | Получение фотографии возврата
*DbsApi* | [**get_returns**](docs/DbsApi.md#get_returns) | **GET** /campaigns/{campaignId}/returns | Список возвратов и невыкупов
*DbsApi* | [**get_suggested_offer_mappings**](docs/DbsApi.md#get_suggested_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/suggestions | Предварительный просмотр карточек на Маркете, соответствующих вашим товарам
*DbsApi* | [**get_warehouses**](docs/DbsApi.md#get_warehouses) | **GET** /businesses/{businessId}/warehouses | Список складов и групп складов
*DbsApi* | [**provide_order_digital_codes**](docs/DbsApi.md#provide_order_digital_codes) | **POST** /campaigns/{campaignId}/orders/{orderId}/deliverDigitalGoods | Передача ключей цифровых товаров
*DbsApi* | [**provide_order_item_identifiers**](docs/DbsApi.md#provide_order_item_identifiers) | **PUT** /campaigns/{campaignId}/orders/{orderId}/identifiers | Передача уникальных кодов маркировки единиц товара (DBS)
*DbsApi* | [**put_bids_for_business**](docs/DbsApi.md#put_bids_for_business) | **PUT** /businesses/{businessId}/bids | Включение буста продаж и установка ставок
*DbsApi* | [**put_bids_for_campaign**](docs/DbsApi.md#put_bids_for_campaign) | **PUT** /campaigns/{campaignId}/bids | Включение буста продаж и установка ставок для магазина
*DbsApi* | [**refresh_feed**](docs/DbsApi.md#refresh_feed) | **POST** /campaigns/{campaignId}/feeds/{feedId}/refresh | Сообщить, что прайс-лист обновился
*DbsApi* | [**search_models**](docs/DbsApi.md#search_models) | **GET** /models | Поиск модели товара
*DbsApi* | [**search_region_children**](docs/DbsApi.md#search_region_children) | **GET** /regions/{regionId}/children | Информация о дочерних регионах
*DbsApi* | [**search_regions_by_id**](docs/DbsApi.md#search_regions_by_id) | **GET** /regions/{regionId} | Информация о регионе
*DbsApi* | [**search_regions_by_name**](docs/DbsApi.md#search_regions_by_name) | **GET** /regions | Метод для поиска регионов по их имени
*DbsApi* | [**send_file_to_chat**](docs/DbsApi.md#send_file_to_chat) | **POST** /businesses/{businessId}/chats/file/send | Отправка файла в чат
*DbsApi* | [**send_message_to_chat**](docs/DbsApi.md#send_message_to_chat) | **POST** /businesses/{businessId}/chats/message | Отправка сообщения в чат
*DbsApi* | [**set_feed_params**](docs/DbsApi.md#set_feed_params) | **POST** /campaigns/{campaignId}/feeds/{feedId}/params | Изменение параметров прайс-листа
*DbsApi* | [**set_order_delivery_date**](docs/DbsApi.md#set_order_delivery_date) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/date | Изменение даты доставки заказа
*DbsApi* | [**set_order_delivery_track_code**](docs/DbsApi.md#set_order_delivery_track_code) | **POST** /campaigns/{campaignId}/orders/{orderId}/delivery/track | Передача трек‑номера посылки (DBS)
*DbsApi* | [**set_order_shipment_boxes**](docs/DbsApi.md#set_order_shipment_boxes) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes | Передача количества грузовых мест в заказе (DBS)
*DbsApi* | [**set_return_decision**](docs/DbsApi.md#set_return_decision) | **POST** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision | Принятие/изменение решения по позиции в возврате
*DbsApi* | [**submit_return_decision**](docs/DbsApi.md#submit_return_decision) | **POST** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/submit | Подтверждение решения по возвратным позициям
*DbsApi* | [**update_business_prices**](docs/DbsApi.md#update_business_prices) | **POST** /businesses/{businessId}/offer-prices/updates | Установка цен
*DbsApi* | [**update_campaign_offers**](docs/DbsApi.md#update_campaign_offers) | **POST** /campaigns/{campaignId}/offers/update | Настройка размещения товаров в магазине
*DbsApi* | [**update_offer_content**](docs/DbsApi.md#update_offer_content) | **POST** /businesses/{businessId}/offer-cards/update | Редактирование категорийных характеристик товара
*DbsApi* | [**update_offer_mappings**](docs/DbsApi.md#update_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/update | Добавление товаров в каталог и редактирование информации о них
*DbsApi* | [**update_order_items**](docs/DbsApi.md#update_order_items) | **PUT** /campaigns/{campaignId}/orders/{orderId}/items | Удаление товара из заказа или уменьшение числа единиц (DBS)
*DbsApi* | [**update_order_status**](docs/DbsApi.md#update_order_status) | **PUT** /campaigns/{campaignId}/orders/{orderId}/status | Изменение статуса заказа
*DbsApi* | [**update_order_statuses**](docs/DbsApi.md#update_order_statuses) | **POST** /campaigns/{campaignId}/orders/status-update | Изменение статусов заказа
*DbsApi* | [**update_order_storage_limit**](docs/DbsApi.md#update_order_storage_limit) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/storage-limit | Продление срока хранения заказа
*DbsApi* | [**update_outlet**](docs/DbsApi.md#update_outlet) | **PUT** /campaigns/{campaignId}/outlets/{outletId} | Изменение информации о точке продаж
*DbsApi* | [**update_outlet_licenses**](docs/DbsApi.md#update_outlet_licenses) | **POST** /campaigns/{campaignId}/outlets/licenses | Создание и изменение лицензий для точек продаж
*DbsApi* | [**update_prices**](docs/DbsApi.md#update_prices) | **POST** /campaigns/{campaignId}/offer-prices/updates | Установка цен на товары в конкретном магазине
*DbsApi* | [**update_stocks**](docs/DbsApi.md#update_stocks) | **PUT** /campaigns/{campaignId}/offers/stocks | Передача информации об остатках
*DeliveryServicesApi* | [**get_delivery_services**](docs/DeliveryServicesApi.md#get_delivery_services) | **GET** /delivery/services | Справочник служб доставки
*ExpressApi* | [**add_offers_to_archive**](docs/ExpressApi.md#add_offers_to_archive) | **POST** /businesses/{businessId}/offer-mappings/archive | Добавление товаров в архив
*ExpressApi* | [**calculate_tariffs**](docs/ExpressApi.md#calculate_tariffs) | **POST** /tariffs/calculate | Калькулятор стоимости услуг
*ExpressApi* | [**confirm_business_prices**](docs/ExpressApi.md#confirm_business_prices) | **POST** /businesses/{businessId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (основная цена)
*ExpressApi* | [**confirm_campaign_prices**](docs/ExpressApi.md#confirm_campaign_prices) | **POST** /campaigns/{campaignId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (цена в магазине)
*ExpressApi* | [**create_chat**](docs/ExpressApi.md#create_chat) | **POST** /businesses/{businessId}/chats/new | Создание нового чата с покупателем
*ExpressApi* | [**delete_campaign_offers**](docs/ExpressApi.md#delete_campaign_offers) | **POST** /campaigns/{campaignId}/offers/delete | Удаление товаров из ассортимента магазина
*ExpressApi* | [**delete_offers**](docs/ExpressApi.md#delete_offers) | **POST** /businesses/{businessId}/offer-mappings/delete | Удаление товаров из каталога
*ExpressApi* | [**delete_offers_from_archive**](docs/ExpressApi.md#delete_offers_from_archive) | **POST** /businesses/{businessId}/offer-mappings/unarchive | Восстановление товаров из архива
*ExpressApi* | [**generate_boost_consolidated_report**](docs/ExpressApi.md#generate_boost_consolidated_report) | **POST** /reports/boost-consolidated/generate | Отчет по бусту продаж
*ExpressApi* | [**generate_goods_realization_report**](docs/ExpressApi.md#generate_goods_realization_report) | **POST** /reports/goods-realization/generate | Отчет по реализации
*ExpressApi* | [**generate_order_label**](docs/ExpressApi.md#generate_order_label) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes/{boxId}/label | Ярлык‑наклейка для коробки в заказе
*ExpressApi* | [**generate_order_labels**](docs/ExpressApi.md#generate_order_labels) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels | Ярлыки‑наклейки на все грузовые места в заказе
*ExpressApi* | [**generate_prices_report**](docs/ExpressApi.md#generate_prices_report) | **POST** /reports/prices/generate | Отчет «Цены на рынке»
*ExpressApi* | [**generate_shows_sales_report**](docs/ExpressApi.md#generate_shows_sales_report) | **POST** /reports/shows-sales/generate | Отчет «Аналитика продаж»
*ExpressApi* | [**generate_stocks_on_warehouses_report**](docs/ExpressApi.md#generate_stocks_on_warehouses_report) | **POST** /reports/stocks-on-warehouses/generate | Отчет по остаткам на складах
*ExpressApi* | [**generate_united_marketplace_services_report**](docs/ExpressApi.md#generate_united_marketplace_services_report) | **POST** /reports/united-marketplace-services/generate | Отчет по стоимости услуг
*ExpressApi* | [**generate_united_netting_report**](docs/ExpressApi.md#generate_united_netting_report) | **POST** /reports/united-netting/generate | Отчет по платежам
*ExpressApi* | [**generate_united_orders_report**](docs/ExpressApi.md#generate_united_orders_report) | **POST** /reports/united-orders/generate | Отчет по заказам
*ExpressApi* | [**get_bids_info_for_business**](docs/ExpressApi.md#get_bids_info_for_business) | **POST** /businesses/{businessId}/bids/info | Информация об установленных ставках
*ExpressApi* | [**get_bids_recommendations**](docs/ExpressApi.md#get_bids_recommendations) | **POST** /businesses/{businessId}/bids/recommendations | Рекомендованные ставки для заданных товаров
*ExpressApi* | [**get_business_quarantine_offers**](docs/ExpressApi.md#get_business_quarantine_offers) | **POST** /businesses/{businessId}/price-quarantine | Список товаров, находящихся в карантине (основная цена)
*ExpressApi* | [**get_campaign**](docs/ExpressApi.md#get_campaign) | **GET** /campaigns/{campaignId} | Информация о магазине
*ExpressApi* | [**get_campaign_logins**](docs/ExpressApi.md#get_campaign_logins) | **GET** /campaigns/{campaignId}/logins | Логины, связанные с магазином
*ExpressApi* | [**get_campaign_offers**](docs/ExpressApi.md#get_campaign_offers) | **POST** /campaigns/{campaignId}/offers | Список товаров, размещенных в заданном магазине, с параметрами размещения
*ExpressApi* | [**get_campaign_quarantine_offers**](docs/ExpressApi.md#get_campaign_quarantine_offers) | **POST** /campaigns/{campaignId}/price-quarantine | Список товаров, находящихся в карантине (цена в магазине)
*ExpressApi* | [**get_campaigns**](docs/ExpressApi.md#get_campaigns) | **GET** /campaigns | Магазины пользователя
*ExpressApi* | [**get_campaigns_by_login**](docs/ExpressApi.md#get_campaigns_by_login) | **GET** /campaigns/by_login/{login} | Магазины, доступные логину
*ExpressApi* | [**get_categories_tree**](docs/ExpressApi.md#get_categories_tree) | **POST** /categories/tree | Дерево категорий
*ExpressApi* | [**get_category_content_parameters**](docs/ExpressApi.md#get_category_content_parameters) | **POST** /category/{categoryId}/parameters | Списки характеристик товаров по категориям
*ExpressApi* | [**get_chat_history**](docs/ExpressApi.md#get_chat_history) | **POST** /businesses/{businessId}/chats/history | Получение истории сообщений в чате
*ExpressApi* | [**get_chats**](docs/ExpressApi.md#get_chats) | **POST** /businesses/{businessId}/chats | Получение доступных чатов
*ExpressApi* | [**get_delivery_services**](docs/ExpressApi.md#get_delivery_services) | **GET** /delivery/services | Справочник служб доставки
*ExpressApi* | [**get_goods_stats**](docs/ExpressApi.md#get_goods_stats) | **POST** /campaigns/{campaignId}/stats/skus | Отчет по товарам
*ExpressApi* | [**get_offer_cards_content_status**](docs/ExpressApi.md#get_offer_cards_content_status) | **POST** /businesses/{businessId}/offer-cards | Получение информации о заполненности карточек
*ExpressApi* | [**get_offer_mapping_entries**](docs/ExpressApi.md#get_offer_mapping_entries) | **GET** /campaigns/{campaignId}/offer-mapping-entries | Список товаров в каталоге
*ExpressApi* | [**get_offer_mappings**](docs/ExpressApi.md#get_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings | Информация о товарах в каталоге
*ExpressApi* | [**get_offer_recommendations**](docs/ExpressApi.md#get_offer_recommendations) | **POST** /businesses/{businessId}/offers/recommendations | Рекомендации Маркета, касающиеся цен
*ExpressApi* | [**get_order**](docs/ExpressApi.md#get_order) | **GET** /campaigns/{campaignId}/orders/{orderId} | Информация о заказе
*ExpressApi* | [**get_order_labels_data**](docs/ExpressApi.md#get_order_labels_data) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels/data | Информация на ярлыках‑наклейках
*ExpressApi* | [**get_orders**](docs/ExpressApi.md#get_orders) | **GET** /campaigns/{campaignId}/orders | Информация о заказах
*ExpressApi* | [**get_orders_stats**](docs/ExpressApi.md#get_orders_stats) | **POST** /campaigns/{campaignId}/stats/orders | Детальная информация по заказам
*ExpressApi* | [**get_prices**](docs/ExpressApi.md#get_prices) | **GET** /campaigns/{campaignId}/offer-prices | Список цен
*ExpressApi* | [**get_prices_by_offer_ids**](docs/ExpressApi.md#get_prices_by_offer_ids) | **POST** /campaigns/{campaignId}/offer-prices | Просмотр установленных в магазине цен
*ExpressApi* | [**get_report_info**](docs/ExpressApi.md#get_report_info) | **GET** /reports/info/{reportId} | Статус генерации и скачивание готовых отчетов
*ExpressApi* | [**get_return**](docs/ExpressApi.md#get_return) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId} | Информация о возврате или невыкупе
*ExpressApi* | [**get_return_application**](docs/ExpressApi.md#get_return_application) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/application | Получение заявления на возврат
*ExpressApi* | [**get_return_photo**](docs/ExpressApi.md#get_return_photo) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/{itemId}/image/{imageHash} | Получение фотографии возврата
*ExpressApi* | [**get_returns**](docs/ExpressApi.md#get_returns) | **GET** /campaigns/{campaignId}/returns | Список возвратов и невыкупов
*ExpressApi* | [**get_suggested_offer_mapping_entries**](docs/ExpressApi.md#get_suggested_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/suggestions | Рекомендованные карточки для ваших товаров
*ExpressApi* | [**get_suggested_offer_mappings**](docs/ExpressApi.md#get_suggested_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/suggestions | Предварительный просмотр карточек на Маркете, соответствующих вашим товарам
*ExpressApi* | [**get_suggested_prices**](docs/ExpressApi.md#get_suggested_prices) | **POST** /campaigns/{campaignId}/offer-prices/suggestions | Цены для продвижения товаров
*ExpressApi* | [**get_warehouses**](docs/ExpressApi.md#get_warehouses) | **GET** /businesses/{businessId}/warehouses | Список складов и групп складов
*ExpressApi* | [**provide_order_item_identifiers**](docs/ExpressApi.md#provide_order_item_identifiers) | **PUT** /campaigns/{campaignId}/orders/{orderId}/identifiers | Передача уникальных кодов маркировки единиц товара (DBS)
*ExpressApi* | [**put_bids_for_business**](docs/ExpressApi.md#put_bids_for_business) | **PUT** /businesses/{businessId}/bids | Включение буста продаж и установка ставок
*ExpressApi* | [**send_file_to_chat**](docs/ExpressApi.md#send_file_to_chat) | **POST** /businesses/{businessId}/chats/file/send | Отправка файла в чат
*ExpressApi* | [**send_message_to_chat**](docs/ExpressApi.md#send_message_to_chat) | **POST** /businesses/{businessId}/chats/message | Отправка сообщения в чат
*ExpressApi* | [**set_order_box_layout**](docs/ExpressApi.md#set_order_box_layout) | **PUT** /campaigns/{campaignId}/orders/{orderId}/boxes | Подготовка заказа (FBS)
*ExpressApi* | [**set_order_shipment_boxes**](docs/ExpressApi.md#set_order_shipment_boxes) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes | Передача количества грузовых мест в заказе (DBS)
*ExpressApi* | [**update_business_prices**](docs/ExpressApi.md#update_business_prices) | **POST** /businesses/{businessId}/offer-prices/updates | Установка цен
*ExpressApi* | [**update_campaign_offers**](docs/ExpressApi.md#update_campaign_offers) | **POST** /campaigns/{campaignId}/offers/update | Настройка размещения товаров в магазине
*ExpressApi* | [**update_offer_content**](docs/ExpressApi.md#update_offer_content) | **POST** /businesses/{businessId}/offer-cards/update | Редактирование категорийных характеристик товара
*ExpressApi* | [**update_offer_mapping_entries**](docs/ExpressApi.md#update_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/updates | Добавление и редактирование товаров в каталоге
*ExpressApi* | [**update_offer_mappings**](docs/ExpressApi.md#update_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/update | Добавление товаров в каталог и редактирование информации о них
*ExpressApi* | [**update_order_items**](docs/ExpressApi.md#update_order_items) | **PUT** /campaigns/{campaignId}/orders/{orderId}/items | Удаление товара из заказа или уменьшение числа единиц (DBS)
*ExpressApi* | [**update_order_status**](docs/ExpressApi.md#update_order_status) | **PUT** /campaigns/{campaignId}/orders/{orderId}/status | Изменение статуса заказа
*ExpressApi* | [**update_order_statuses**](docs/ExpressApi.md#update_order_statuses) | **POST** /campaigns/{campaignId}/orders/status-update | Изменение статусов заказа
*ExpressApi* | [**update_prices**](docs/ExpressApi.md#update_prices) | **POST** /campaigns/{campaignId}/offer-prices/updates | Установка цен на товары в конкретном магазине
*ExpressApi* | [**update_stocks**](docs/ExpressApi.md#update_stocks) | **PUT** /campaigns/{campaignId}/offers/stocks | Передача информации об остатках
*ExpressApi* | [**verify_order_eac**](docs/ExpressApi.md#verify_order_eac) | **PUT** /campaigns/{campaignId}/orders/{orderId}/verifyEac | Передача кода проверки
*FbsApi* | [**add_hidden_offers**](docs/FbsApi.md#add_hidden_offers) | **POST** /campaigns/{campaignId}/hidden-offers | Скрытие товаров и настройки скрытия
*FbsApi* | [**add_offers_to_archive**](docs/FbsApi.md#add_offers_to_archive) | **POST** /businesses/{businessId}/offer-mappings/archive | Добавление товаров в архив
*FbsApi* | [**calculate_tariffs**](docs/FbsApi.md#calculate_tariffs) | **POST** /tariffs/calculate | Калькулятор стоимости услуг
*FbsApi* | [**confirm_business_prices**](docs/FbsApi.md#confirm_business_prices) | **POST** /businesses/{businessId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (основная цена)
*FbsApi* | [**confirm_campaign_prices**](docs/FbsApi.md#confirm_campaign_prices) | **POST** /campaigns/{campaignId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (цена в магазине)
*FbsApi* | [**confirm_shipment**](docs/FbsApi.md#confirm_shipment) | **POST** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/confirm | Подтверждение отгрузки
*FbsApi* | [**create_chat**](docs/FbsApi.md#create_chat) | **POST** /businesses/{businessId}/chats/new | Создание нового чата с покупателем
*FbsApi* | [**delete_campaign_offers**](docs/FbsApi.md#delete_campaign_offers) | **POST** /campaigns/{campaignId}/offers/delete | Удаление товаров из ассортимента магазина
*FbsApi* | [**delete_hidden_offers**](docs/FbsApi.md#delete_hidden_offers) | **DELETE** /campaigns/{campaignId}/hidden-offers | Возобновление показа товаров
*FbsApi* | [**delete_offers**](docs/FbsApi.md#delete_offers) | **POST** /businesses/{businessId}/offer-mappings/delete | Удаление товаров из каталога
*FbsApi* | [**delete_offers_from_archive**](docs/FbsApi.md#delete_offers_from_archive) | **POST** /businesses/{businessId}/offer-mappings/unarchive | Восстановление товаров из архива
*FbsApi* | [**download_shipment_act**](docs/FbsApi.md#download_shipment_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/act | Получение акта приема-передачи
*FbsApi* | [**download_shipment_discrepancy_act**](docs/FbsApi.md#download_shipment_discrepancy_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/discrepancy-act | Получение акта расхождений
*FbsApi* | [**download_shipment_inbound_act**](docs/FbsApi.md#download_shipment_inbound_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/inbound-act | Получение фактического акта приема-передачи
*FbsApi* | [**download_shipment_pallet_labels**](docs/FbsApi.md#download_shipment_pallet_labels) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/pallet/labels | Ярлыки на все упаковки в отгрузке
*FbsApi* | [**download_shipment_reception_transfer_act**](docs/FbsApi.md#download_shipment_reception_transfer_act) | **GET** /campaigns/{campaignId}/shipments/reception-transfer-act | Подтверждение ближайшей отгрузки и получение акта приема-передачи для нее
*FbsApi* | [**download_shipment_transportation_waybill**](docs/FbsApi.md#download_shipment_transportation_waybill) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/transportation-waybill | Получение транспортной накладной
*FbsApi* | [**generate_boost_consolidated_report**](docs/FbsApi.md#generate_boost_consolidated_report) | **POST** /reports/boost-consolidated/generate | Отчет по бусту продаж
*FbsApi* | [**generate_goods_realization_report**](docs/FbsApi.md#generate_goods_realization_report) | **POST** /reports/goods-realization/generate | Отчет по реализации
*FbsApi* | [**generate_order_label**](docs/FbsApi.md#generate_order_label) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes/{boxId}/label | Ярлык‑наклейка для коробки в заказе
*FbsApi* | [**generate_order_labels**](docs/FbsApi.md#generate_order_labels) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels | Ярлыки‑наклейки на все грузовые места в заказе
*FbsApi* | [**generate_prices_report**](docs/FbsApi.md#generate_prices_report) | **POST** /reports/prices/generate | Отчет «Цены на рынке»
*FbsApi* | [**generate_shipment_list_document_report**](docs/FbsApi.md#generate_shipment_list_document_report) | **POST** /reports/documents/shipment-list/generate | Лист сборки
*FbsApi* | [**generate_shows_sales_report**](docs/FbsApi.md#generate_shows_sales_report) | **POST** /reports/shows-sales/generate | Отчет «Аналитика продаж»
*FbsApi* | [**generate_stocks_on_warehouses_report**](docs/FbsApi.md#generate_stocks_on_warehouses_report) | **POST** /reports/stocks-on-warehouses/generate | Отчет по остаткам на складах
*FbsApi* | [**generate_united_marketplace_services_report**](docs/FbsApi.md#generate_united_marketplace_services_report) | **POST** /reports/united-marketplace-services/generate | Отчет по стоимости услуг
*FbsApi* | [**generate_united_netting_report**](docs/FbsApi.md#generate_united_netting_report) | **POST** /reports/united-netting/generate | Отчет по платежам
*FbsApi* | [**generate_united_orders_report**](docs/FbsApi.md#generate_united_orders_report) | **POST** /reports/united-orders/generate | Отчет по заказам
*FbsApi* | [**get_bids_info_for_business**](docs/FbsApi.md#get_bids_info_for_business) | **POST** /businesses/{businessId}/bids/info | Информация об установленных ставках
*FbsApi* | [**get_bids_recommendations**](docs/FbsApi.md#get_bids_recommendations) | **POST** /businesses/{businessId}/bids/recommendations | Рекомендованные ставки для заданных товаров
*FbsApi* | [**get_business_quarantine_offers**](docs/FbsApi.md#get_business_quarantine_offers) | **POST** /businesses/{businessId}/price-quarantine | Список товаров, находящихся в карантине (основная цена)
*FbsApi* | [**get_campaign**](docs/FbsApi.md#get_campaign) | **GET** /campaigns/{campaignId} | Информация о магазине
*FbsApi* | [**get_campaign_logins**](docs/FbsApi.md#get_campaign_logins) | **GET** /campaigns/{campaignId}/logins | Логины, связанные с магазином
*FbsApi* | [**get_campaign_offers**](docs/FbsApi.md#get_campaign_offers) | **POST** /campaigns/{campaignId}/offers | Список товаров, размещенных в заданном магазине, с параметрами размещения
*FbsApi* | [**get_campaign_quarantine_offers**](docs/FbsApi.md#get_campaign_quarantine_offers) | **POST** /campaigns/{campaignId}/price-quarantine | Список товаров, находящихся в карантине (цена в магазине)
*FbsApi* | [**get_campaigns**](docs/FbsApi.md#get_campaigns) | **GET** /campaigns | Магазины пользователя
*FbsApi* | [**get_campaigns_by_login**](docs/FbsApi.md#get_campaigns_by_login) | **GET** /campaigns/by_login/{login} | Магазины, доступные логину
*FbsApi* | [**get_categories_tree**](docs/FbsApi.md#get_categories_tree) | **POST** /categories/tree | Дерево категорий
*FbsApi* | [**get_category_content_parameters**](docs/FbsApi.md#get_category_content_parameters) | **POST** /category/{categoryId}/parameters | Списки характеристик товаров по категориям
*FbsApi* | [**get_chat_history**](docs/FbsApi.md#get_chat_history) | **POST** /businesses/{businessId}/chats/history | Получение истории сообщений в чате
*FbsApi* | [**get_chats**](docs/FbsApi.md#get_chats) | **POST** /businesses/{businessId}/chats | Получение доступных чатов
*FbsApi* | [**get_delivery_services**](docs/FbsApi.md#get_delivery_services) | **GET** /delivery/services | Справочник служб доставки
*FbsApi* | [**get_goods_stats**](docs/FbsApi.md#get_goods_stats) | **POST** /campaigns/{campaignId}/stats/skus | Отчет по товарам
*FbsApi* | [**get_hidden_offers**](docs/FbsApi.md#get_hidden_offers) | **GET** /campaigns/{campaignId}/hidden-offers | Информация о скрытых вами товарах
*FbsApi* | [**get_offer_cards_content_status**](docs/FbsApi.md#get_offer_cards_content_status) | **POST** /businesses/{businessId}/offer-cards | Получение информации о заполненности карточек
*FbsApi* | [**get_offer_mapping_entries**](docs/FbsApi.md#get_offer_mapping_entries) | **GET** /campaigns/{campaignId}/offer-mapping-entries | Список товаров в каталоге
*FbsApi* | [**get_offer_mappings**](docs/FbsApi.md#get_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings | Информация о товарах в каталоге
*FbsApi* | [**get_offer_recommendations**](docs/FbsApi.md#get_offer_recommendations) | **POST** /businesses/{businessId}/offers/recommendations | Рекомендации Маркета, касающиеся цен
*FbsApi* | [**get_order**](docs/FbsApi.md#get_order) | **GET** /campaigns/{campaignId}/orders/{orderId} | Информация о заказе
*FbsApi* | [**get_order_business_buyer_info**](docs/FbsApi.md#get_order_business_buyer_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/business-buyer | Информация о покупателе — юридическом лице
*FbsApi* | [**get_order_business_documents_info**](docs/FbsApi.md#get_order_business_documents_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/documents | Информация о документах
*FbsApi* | [**get_order_labels_data**](docs/FbsApi.md#get_order_labels_data) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels/data | Информация на ярлыках‑наклейках
*FbsApi* | [**get_orders**](docs/FbsApi.md#get_orders) | **GET** /campaigns/{campaignId}/orders | Информация о заказах
*FbsApi* | [**get_orders_stats**](docs/FbsApi.md#get_orders_stats) | **POST** /campaigns/{campaignId}/stats/orders | Детальная информация по заказам
*FbsApi* | [**get_prices**](docs/FbsApi.md#get_prices) | **GET** /campaigns/{campaignId}/offer-prices | Список цен
*FbsApi* | [**get_prices_by_offer_ids**](docs/FbsApi.md#get_prices_by_offer_ids) | **POST** /campaigns/{campaignId}/offer-prices | Просмотр установленных в магазине цен
*FbsApi* | [**get_report_info**](docs/FbsApi.md#get_report_info) | **GET** /reports/info/{reportId} | Статус генерации и скачивание готовых отчетов
*FbsApi* | [**get_return**](docs/FbsApi.md#get_return) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId} | Информация о возврате или невыкупе
*FbsApi* | [**get_return_application**](docs/FbsApi.md#get_return_application) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/application | Получение заявления на возврат
*FbsApi* | [**get_return_photo**](docs/FbsApi.md#get_return_photo) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/{itemId}/image/{imageHash} | Получение фотографии возврата
*FbsApi* | [**get_returns**](docs/FbsApi.md#get_returns) | **GET** /campaigns/{campaignId}/returns | Список возвратов и невыкупов
*FbsApi* | [**get_shipment**](docs/FbsApi.md#get_shipment) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId} | Получение информации об отгрузке
*FbsApi* | [**get_shipment_orders_info**](docs/FbsApi.md#get_shipment_orders_info) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/orders/info | Получение информации о ярлыках
*FbsApi* | [**get_stocks**](docs/FbsApi.md#get_stocks) | **POST** /campaigns/{campaignId}/offers/stocks | Информация об остатках и оборачиваемости
*FbsApi* | [**get_suggested_offer_mapping_entries**](docs/FbsApi.md#get_suggested_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/suggestions | Рекомендованные карточки для ваших товаров
*FbsApi* | [**get_suggested_offer_mappings**](docs/FbsApi.md#get_suggested_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/suggestions | Предварительный просмотр карточек на Маркете, соответствующих вашим товарам
*FbsApi* | [**get_suggested_prices**](docs/FbsApi.md#get_suggested_prices) | **POST** /campaigns/{campaignId}/offer-prices/suggestions | Цены для продвижения товаров
*FbsApi* | [**get_warehouses**](docs/FbsApi.md#get_warehouses) | **GET** /businesses/{businessId}/warehouses | Список складов и групп складов
*FbsApi* | [**provide_order_item_identifiers**](docs/FbsApi.md#provide_order_item_identifiers) | **PUT** /campaigns/{campaignId}/orders/{orderId}/identifiers | Передача уникальных кодов маркировки единиц товара (DBS)
*FbsApi* | [**put_bids_for_business**](docs/FbsApi.md#put_bids_for_business) | **PUT** /businesses/{businessId}/bids | Включение буста продаж и установка ставок
*FbsApi* | [**search_region_children**](docs/FbsApi.md#search_region_children) | **GET** /regions/{regionId}/children | Информация о дочерних регионах
*FbsApi* | [**search_regions_by_id**](docs/FbsApi.md#search_regions_by_id) | **GET** /regions/{regionId} | Информация о регионе
*FbsApi* | [**search_regions_by_name**](docs/FbsApi.md#search_regions_by_name) | **GET** /regions | Метод для поиска регионов по их имени
*FbsApi* | [**search_shipments**](docs/FbsApi.md#search_shipments) | **PUT** /campaigns/{campaignId}/first-mile/shipments | Получение информации об отгрузках
*FbsApi* | [**send_file_to_chat**](docs/FbsApi.md#send_file_to_chat) | **POST** /businesses/{businessId}/chats/file/send | Отправка файла в чат
*FbsApi* | [**send_message_to_chat**](docs/FbsApi.md#send_message_to_chat) | **POST** /businesses/{businessId}/chats/message | Отправка сообщения в чат
*FbsApi* | [**set_order_box_layout**](docs/FbsApi.md#set_order_box_layout) | **PUT** /campaigns/{campaignId}/orders/{orderId}/boxes | Подготовка заказа (FBS)
*FbsApi* | [**set_order_shipment_boxes**](docs/FbsApi.md#set_order_shipment_boxes) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes | Передача количества грузовых мест в заказе (DBS)
*FbsApi* | [**set_shipment_pallets_count**](docs/FbsApi.md#set_shipment_pallets_count) | **PUT** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/pallets | Передача количества упаковок в отгрузке
*FbsApi* | [**transfer_orders_from_shipment**](docs/FbsApi.md#transfer_orders_from_shipment) | **POST** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/orders/transfer | Перенос заказов в следующую отгрузку
*FbsApi* | [**update_business_prices**](docs/FbsApi.md#update_business_prices) | **POST** /businesses/{businessId}/offer-prices/updates | Установка цен
*FbsApi* | [**update_campaign_offers**](docs/FbsApi.md#update_campaign_offers) | **POST** /campaigns/{campaignId}/offers/update | Настройка размещения товаров в магазине
*FbsApi* | [**update_offer_content**](docs/FbsApi.md#update_offer_content) | **POST** /businesses/{businessId}/offer-cards/update | Редактирование категорийных характеристик товара
*FbsApi* | [**update_offer_mapping_entries**](docs/FbsApi.md#update_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/updates | Добавление и редактирование товаров в каталоге
*FbsApi* | [**update_offer_mappings**](docs/FbsApi.md#update_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/update | Добавление товаров в каталог и редактирование информации о них
*FbsApi* | [**update_order_items**](docs/FbsApi.md#update_order_items) | **PUT** /campaigns/{campaignId}/orders/{orderId}/items | Удаление товара из заказа или уменьшение числа единиц (DBS)
*FbsApi* | [**update_order_status**](docs/FbsApi.md#update_order_status) | **PUT** /campaigns/{campaignId}/orders/{orderId}/status | Изменение статуса заказа
*FbsApi* | [**update_order_statuses**](docs/FbsApi.md#update_order_statuses) | **POST** /campaigns/{campaignId}/orders/status-update | Изменение статусов заказа
*FbsApi* | [**update_prices**](docs/FbsApi.md#update_prices) | **POST** /campaigns/{campaignId}/offer-prices/updates | Установка цен на товары в конкретном магазине
*FbsApi* | [**update_stocks**](docs/FbsApi.md#update_stocks) | **PUT** /campaigns/{campaignId}/offers/stocks | Передача информации об остатках
*FbyApi* | [**add_hidden_offers**](docs/FbyApi.md#add_hidden_offers) | **POST** /campaigns/{campaignId}/hidden-offers | Скрытие товаров и настройки скрытия
*FbyApi* | [**add_offers_to_archive**](docs/FbyApi.md#add_offers_to_archive) | **POST** /businesses/{businessId}/offer-mappings/archive | Добавление товаров в архив
*FbyApi* | [**calculate_tariffs**](docs/FbyApi.md#calculate_tariffs) | **POST** /tariffs/calculate | Калькулятор стоимости услуг
*FbyApi* | [**confirm_business_prices**](docs/FbyApi.md#confirm_business_prices) | **POST** /businesses/{businessId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (основная цена)
*FbyApi* | [**confirm_campaign_prices**](docs/FbyApi.md#confirm_campaign_prices) | **POST** /campaigns/{campaignId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (цена в магазине)
*FbyApi* | [**create_chat**](docs/FbyApi.md#create_chat) | **POST** /businesses/{businessId}/chats/new | Создание нового чата с покупателем
*FbyApi* | [**delete_campaign_offers**](docs/FbyApi.md#delete_campaign_offers) | **POST** /campaigns/{campaignId}/offers/delete | Удаление товаров из ассортимента магазина
*FbyApi* | [**delete_hidden_offers**](docs/FbyApi.md#delete_hidden_offers) | **DELETE** /campaigns/{campaignId}/hidden-offers | Возобновление показа товаров
*FbyApi* | [**delete_offers**](docs/FbyApi.md#delete_offers) | **POST** /businesses/{businessId}/offer-mappings/delete | Удаление товаров из каталога
*FbyApi* | [**delete_offers_from_archive**](docs/FbyApi.md#delete_offers_from_archive) | **POST** /businesses/{businessId}/offer-mappings/unarchive | Восстановление товаров из архива
*FbyApi* | [**generate_boost_consolidated_report**](docs/FbyApi.md#generate_boost_consolidated_report) | **POST** /reports/boost-consolidated/generate | Отчет по бусту продаж
*FbyApi* | [**generate_goods_movement_report**](docs/FbyApi.md#generate_goods_movement_report) | **POST** /reports/goods-movement/generate | Отчет по движению товаров
*FbyApi* | [**generate_goods_realization_report**](docs/FbyApi.md#generate_goods_realization_report) | **POST** /reports/goods-realization/generate | Отчет по реализации
*FbyApi* | [**generate_goods_turnover_report**](docs/FbyApi.md#generate_goods_turnover_report) | **POST** /reports/goods-turnover/generate | Отчет по оборачиваемости
*FbyApi* | [**generate_prices_report**](docs/FbyApi.md#generate_prices_report) | **POST** /reports/prices/generate | Отчет «Цены на рынке»
*FbyApi* | [**generate_shows_sales_report**](docs/FbyApi.md#generate_shows_sales_report) | **POST** /reports/shows-sales/generate | Отчет «Аналитика продаж»
*FbyApi* | [**generate_stocks_on_warehouses_report**](docs/FbyApi.md#generate_stocks_on_warehouses_report) | **POST** /reports/stocks-on-warehouses/generate | Отчет по остаткам на складах
*FbyApi* | [**generate_united_marketplace_services_report**](docs/FbyApi.md#generate_united_marketplace_services_report) | **POST** /reports/united-marketplace-services/generate | Отчет по стоимости услуг
*FbyApi* | [**generate_united_netting_report**](docs/FbyApi.md#generate_united_netting_report) | **POST** /reports/united-netting/generate | Отчет по платежам
*FbyApi* | [**generate_united_orders_report**](docs/FbyApi.md#generate_united_orders_report) | **POST** /reports/united-orders/generate | Отчет по заказам
*FbyApi* | [**get_bids_info_for_business**](docs/FbyApi.md#get_bids_info_for_business) | **POST** /businesses/{businessId}/bids/info | Информация об установленных ставках
*FbyApi* | [**get_bids_recommendations**](docs/FbyApi.md#get_bids_recommendations) | **POST** /businesses/{businessId}/bids/recommendations | Рекомендованные ставки для заданных товаров
*FbyApi* | [**get_business_quarantine_offers**](docs/FbyApi.md#get_business_quarantine_offers) | **POST** /businesses/{businessId}/price-quarantine | Список товаров, находящихся в карантине (основная цена)
*FbyApi* | [**get_campaign**](docs/FbyApi.md#get_campaign) | **GET** /campaigns/{campaignId} | Информация о магазине
*FbyApi* | [**get_campaign_logins**](docs/FbyApi.md#get_campaign_logins) | **GET** /campaigns/{campaignId}/logins | Логины, связанные с магазином
*FbyApi* | [**get_campaign_offers**](docs/FbyApi.md#get_campaign_offers) | **POST** /campaigns/{campaignId}/offers | Список товаров, размещенных в заданном магазине, с параметрами размещения
*FbyApi* | [**get_campaign_quarantine_offers**](docs/FbyApi.md#get_campaign_quarantine_offers) | **POST** /campaigns/{campaignId}/price-quarantine | Список товаров, находящихся в карантине (цена в магазине)
*FbyApi* | [**get_campaigns**](docs/FbyApi.md#get_campaigns) | **GET** /campaigns | Магазины пользователя
*FbyApi* | [**get_campaigns_by_login**](docs/FbyApi.md#get_campaigns_by_login) | **GET** /campaigns/by_login/{login} | Магазины, доступные логину
*FbyApi* | [**get_categories_tree**](docs/FbyApi.md#get_categories_tree) | **POST** /categories/tree | Дерево категорий
*FbyApi* | [**get_category_content_parameters**](docs/FbyApi.md#get_category_content_parameters) | **POST** /category/{categoryId}/parameters | Списки характеристик товаров по категориям
*FbyApi* | [**get_chat_history**](docs/FbyApi.md#get_chat_history) | **POST** /businesses/{businessId}/chats/history | Получение истории сообщений в чате
*FbyApi* | [**get_chats**](docs/FbyApi.md#get_chats) | **POST** /businesses/{businessId}/chats | Получение доступных чатов
*FbyApi* | [**get_fulfillment_warehouses**](docs/FbyApi.md#get_fulfillment_warehouses) | **GET** /warehouses | Идентификаторы складов Маркета (FBY)
*FbyApi* | [**get_goods_stats**](docs/FbyApi.md#get_goods_stats) | **POST** /campaigns/{campaignId}/stats/skus | Отчет по товарам
*FbyApi* | [**get_hidden_offers**](docs/FbyApi.md#get_hidden_offers) | **GET** /campaigns/{campaignId}/hidden-offers | Информация о скрытых вами товарах
*FbyApi* | [**get_offer_cards_content_status**](docs/FbyApi.md#get_offer_cards_content_status) | **POST** /businesses/{businessId}/offer-cards | Получение информации о заполненности карточек
*FbyApi* | [**get_offer_mapping_entries**](docs/FbyApi.md#get_offer_mapping_entries) | **GET** /campaigns/{campaignId}/offer-mapping-entries | Список товаров в каталоге
*FbyApi* | [**get_offer_mappings**](docs/FbyApi.md#get_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings | Информация о товарах в каталоге
*FbyApi* | [**get_offer_recommendations**](docs/FbyApi.md#get_offer_recommendations) | **POST** /businesses/{businessId}/offers/recommendations | Рекомендации Маркета, касающиеся цен
*FbyApi* | [**get_order**](docs/FbyApi.md#get_order) | **GET** /campaigns/{campaignId}/orders/{orderId} | Информация о заказе
*FbyApi* | [**get_order_business_buyer_info**](docs/FbyApi.md#get_order_business_buyer_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/business-buyer | Информация о покупателе — юридическом лице
*FbyApi* | [**get_order_business_documents_info**](docs/FbyApi.md#get_order_business_documents_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/documents | Информация о документах
*FbyApi* | [**get_orders_stats**](docs/FbyApi.md#get_orders_stats) | **POST** /campaigns/{campaignId}/stats/orders | Детальная информация по заказам
*FbyApi* | [**get_prices**](docs/FbyApi.md#get_prices) | **GET** /campaigns/{campaignId}/offer-prices | Список цен
*FbyApi* | [**get_prices_by_offer_ids**](docs/FbyApi.md#get_prices_by_offer_ids) | **POST** /campaigns/{campaignId}/offer-prices | Просмотр установленных в магазине цен
*FbyApi* | [**get_report_info**](docs/FbyApi.md#get_report_info) | **GET** /reports/info/{reportId} | Статус генерации и скачивание готовых отчетов
*FbyApi* | [**get_stocks**](docs/FbyApi.md#get_stocks) | **POST** /campaigns/{campaignId}/offers/stocks | Информация об остатках и оборачиваемости
*FbyApi* | [**get_suggested_offer_mapping_entries**](docs/FbyApi.md#get_suggested_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/suggestions | Рекомендованные карточки для ваших товаров
*FbyApi* | [**get_suggested_offer_mappings**](docs/FbyApi.md#get_suggested_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/suggestions | Предварительный просмотр карточек на Маркете, соответствующих вашим товарам
*FbyApi* | [**get_suggested_prices**](docs/FbyApi.md#get_suggested_prices) | **POST** /campaigns/{campaignId}/offer-prices/suggestions | Цены для продвижения товаров
*FbyApi* | [**put_bids_for_business**](docs/FbyApi.md#put_bids_for_business) | **PUT** /businesses/{businessId}/bids | Включение буста продаж и установка ставок
*FbyApi* | [**search_region_children**](docs/FbyApi.md#search_region_children) | **GET** /regions/{regionId}/children | Информация о дочерних регионах
*FbyApi* | [**search_regions_by_id**](docs/FbyApi.md#search_regions_by_id) | **GET** /regions/{regionId} | Информация о регионе
*FbyApi* | [**search_regions_by_name**](docs/FbyApi.md#search_regions_by_name) | **GET** /regions | Метод для поиска регионов по их имени
*FbyApi* | [**send_file_to_chat**](docs/FbyApi.md#send_file_to_chat) | **POST** /businesses/{businessId}/chats/file/send | Отправка файла в чат
*FbyApi* | [**send_message_to_chat**](docs/FbyApi.md#send_message_to_chat) | **POST** /businesses/{businessId}/chats/message | Отправка сообщения в чат
*FbyApi* | [**update_business_prices**](docs/FbyApi.md#update_business_prices) | **POST** /businesses/{businessId}/offer-prices/updates | Установка цен
*FbyApi* | [**update_campaign_offers**](docs/FbyApi.md#update_campaign_offers) | **POST** /campaigns/{campaignId}/offers/update | Настройка размещения товаров в магазине
*FbyApi* | [**update_offer_content**](docs/FbyApi.md#update_offer_content) | **POST** /businesses/{businessId}/offer-cards/update | Редактирование категорийных характеристик товара
*FbyApi* | [**update_offer_mapping_entries**](docs/FbyApi.md#update_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/updates | Добавление и редактирование товаров в каталоге
*FbyApi* | [**update_offer_mappings**](docs/FbyApi.md#update_offer_mappings) | **POST** /businesses/{businessId}/offer-mappings/update | Добавление товаров в каталог и редактирование информации о них
*FbyApi* | [**update_order_status**](docs/FbyApi.md#update_order_status) | **PUT** /campaigns/{campaignId}/orders/{orderId}/status | Изменение статуса заказа
*FbyApi* | [**update_prices**](docs/FbyApi.md#update_prices) | **POST** /campaigns/{campaignId}/offer-prices/updates | Установка цен на товары в конкретном магазине
*FeedCategoriesApi* | [**get_campaign_feed_categories**](docs/FeedCategoriesApi.md#get_campaign_feed_categories) | **GET** /campaigns/{campaignId}/feeds/categories | Категории магазина
*FeedCategoriesApi* | [**get_feed_categories**](docs/FeedCategoriesApi.md#get_feed_categories) | **GET** /campaigns/{campaignId}/feeds/{feedId}/categories | Категории прайс-листа
*FeedbacksApi* | [**get_feedback_and_comment_updates**](docs/FeedbacksApi.md#get_feedback_and_comment_updates) | **GET** /campaigns/{campaignId}/feedback/updates | Новые и обновленные отзывы о магазине
*FeedsApi* | [**get_feed**](docs/FeedsApi.md#get_feed) | **GET** /campaigns/{campaignId}/feeds/{feedId} | Информация о прайс-листе
*FeedsApi* | [**get_feed_index_logs**](docs/FeedsApi.md#get_feed_index_logs) | **GET** /campaigns/{campaignId}/feeds/{feedId}/index-logs | Отчет по индексации прайс-листа
*FeedsApi* | [**get_feeds**](docs/FeedsApi.md#get_feeds) | **GET** /campaigns/{campaignId}/feeds | Список прайс-листов магазина
*FeedsApi* | [**refresh_feed**](docs/FeedsApi.md#refresh_feed) | **POST** /campaigns/{campaignId}/feeds/{feedId}/refresh | Сообщить, что прайс-лист обновился
*FeedsApi* | [**set_feed_params**](docs/FeedsApi.md#set_feed_params) | **POST** /campaigns/{campaignId}/feeds/{feedId}/params | Изменение параметров прайс-листа
*GoodsStatsApi* | [**get_goods_stats**](docs/GoodsStatsApi.md#get_goods_stats) | **POST** /campaigns/{campaignId}/stats/skus | Отчет по товарам
*HiddenOffersApi* | [**add_hidden_offers**](docs/HiddenOffersApi.md#add_hidden_offers) | **POST** /campaigns/{campaignId}/hidden-offers | Скрытие товаров и настройки скрытия
*HiddenOffersApi* | [**delete_hidden_offers**](docs/HiddenOffersApi.md#delete_hidden_offers) | **DELETE** /campaigns/{campaignId}/hidden-offers | Возобновление показа товаров
*HiddenOffersApi* | [**get_hidden_offers**](docs/HiddenOffersApi.md#get_hidden_offers) | **GET** /campaigns/{campaignId}/hidden-offers | Информация о скрытых вами товарах
*ModelsApi* | [**get_model**](docs/ModelsApi.md#get_model) | **GET** /models/{modelId} | Информация о модели
*ModelsApi* | [**get_model_offers**](docs/ModelsApi.md#get_model_offers) | **GET** /models/{modelId}/offers | Список предложений для модели
*ModelsApi* | [**get_models**](docs/ModelsApi.md#get_models) | **POST** /models | Информация о нескольких моделях
*ModelsApi* | [**get_models_offers**](docs/ModelsApi.md#get_models_offers) | **POST** /models/offers | Список предложений для нескольких моделей
*ModelsApi* | [**search_models**](docs/ModelsApi.md#search_models) | **GET** /models | Поиск модели товара
*OfferMappingsApi* | [**get_offer_mapping_entries**](docs/OfferMappingsApi.md#get_offer_mapping_entries) | **GET** /campaigns/{campaignId}/offer-mapping-entries | Список товаров в каталоге
*OfferMappingsApi* | [**get_suggested_offer_mapping_entries**](docs/OfferMappingsApi.md#get_suggested_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/suggestions | Рекомендованные карточки для ваших товаров
*OfferMappingsApi* | [**update_offer_mapping_entries**](docs/OfferMappingsApi.md#update_offer_mapping_entries) | **POST** /campaigns/{campaignId}/offer-mapping-entries/updates | Добавление и редактирование товаров в каталоге
*OffersApi* | [**delete_campaign_offers**](docs/OffersApi.md#delete_campaign_offers) | **POST** /campaigns/{campaignId}/offers/delete | Удаление товаров из ассортимента магазина
*OffersApi* | [**get_all_offers**](docs/OffersApi.md#get_all_offers) | **GET** /campaigns/{campaignId}/offers/all | Все предложения магазина
*OffersApi* | [**get_campaign_offers**](docs/OffersApi.md#get_campaign_offers) | **POST** /campaigns/{campaignId}/offers | Список товаров, размещенных в заданном магазине, с параметрами размещения
*OffersApi* | [**get_offer_recommendations**](docs/OffersApi.md#get_offer_recommendations) | **POST** /businesses/{businessId}/offers/recommendations | Рекомендации Маркета, касающиеся цен
*OffersApi* | [**get_offers**](docs/OffersApi.md#get_offers) | **GET** /campaigns/{campaignId}/offers | Предложения магазина
*OffersApi* | [**update_campaign_offers**](docs/OffersApi.md#update_campaign_offers) | **POST** /campaigns/{campaignId}/offers/update | Настройка размещения товаров в магазине
*OrderBusinessInformationApi* | [**get_order_business_buyer_info**](docs/OrderBusinessInformationApi.md#get_order_business_buyer_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/business-buyer | Информация о покупателе — юридическом лице
*OrderBusinessInformationApi* | [**get_order_business_documents_info**](docs/OrderBusinessInformationApi.md#get_order_business_documents_info) | **POST** /campaigns/{campaignId}/orders/{orderId}/documents | Информация о документах
*OrderDeliveryApi* | [**get_order_buyer_info**](docs/OrderDeliveryApi.md#get_order_buyer_info) | **GET** /campaigns/{campaignId}/orders/{orderId}/buyer | Информация о покупателе — физическом лице (DBS)
*OrderDeliveryApi* | [**set_order_delivery_date**](docs/OrderDeliveryApi.md#set_order_delivery_date) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/date | Изменение даты доставки заказа
*OrderDeliveryApi* | [**set_order_delivery_track_code**](docs/OrderDeliveryApi.md#set_order_delivery_track_code) | **POST** /campaigns/{campaignId}/orders/{orderId}/delivery/track | Передача трек‑номера посылки (DBS)
*OrderDeliveryApi* | [**update_order_storage_limit**](docs/OrderDeliveryApi.md#update_order_storage_limit) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/storage-limit | Продление срока хранения заказа
*OrderDeliveryApi* | [**verify_order_eac**](docs/OrderDeliveryApi.md#verify_order_eac) | **PUT** /campaigns/{campaignId}/orders/{orderId}/verifyEac | Передача кода проверки
*OrderLabelsApi* | [**generate_order_label**](docs/OrderLabelsApi.md#generate_order_label) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes/{boxId}/label | Ярлык‑наклейка для коробки в заказе
*OrderLabelsApi* | [**generate_order_labels**](docs/OrderLabelsApi.md#generate_order_labels) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels | Ярлыки‑наклейки на все грузовые места в заказе
*OrderLabelsApi* | [**get_order_labels_data**](docs/OrderLabelsApi.md#get_order_labels_data) | **GET** /campaigns/{campaignId}/orders/{orderId}/delivery/labels/data | Информация на ярлыках‑наклейках
*OrdersApi* | [**accept_order_cancellation**](docs/OrdersApi.md#accept_order_cancellation) | **PUT** /campaigns/{campaignId}/orders/{orderId}/cancellation/accept | Отмена заказа покупателем (DBS)
*OrdersApi* | [**get_order**](docs/OrdersApi.md#get_order) | **GET** /campaigns/{campaignId}/orders/{orderId} | Информация о заказе
*OrdersApi* | [**get_orders**](docs/OrdersApi.md#get_orders) | **GET** /campaigns/{campaignId}/orders | Информация о заказах
*OrdersApi* | [**provide_order_digital_codes**](docs/OrdersApi.md#provide_order_digital_codes) | **POST** /campaigns/{campaignId}/orders/{orderId}/deliverDigitalGoods | Передача ключей цифровых товаров
*OrdersApi* | [**provide_order_item_identifiers**](docs/OrdersApi.md#provide_order_item_identifiers) | **PUT** /campaigns/{campaignId}/orders/{orderId}/identifiers | Передача уникальных кодов маркировки единиц товара (DBS)
*OrdersApi* | [**set_order_box_layout**](docs/OrdersApi.md#set_order_box_layout) | **PUT** /campaigns/{campaignId}/orders/{orderId}/boxes | Подготовка заказа (FBS)
*OrdersApi* | [**set_order_shipment_boxes**](docs/OrdersApi.md#set_order_shipment_boxes) | **PUT** /campaigns/{campaignId}/orders/{orderId}/delivery/shipments/{shipmentId}/boxes | Передача количества грузовых мест в заказе (DBS)
*OrdersApi* | [**update_order_items**](docs/OrdersApi.md#update_order_items) | **PUT** /campaigns/{campaignId}/orders/{orderId}/items | Удаление товара из заказа или уменьшение числа единиц (DBS)
*OrdersApi* | [**update_order_status**](docs/OrdersApi.md#update_order_status) | **PUT** /campaigns/{campaignId}/orders/{orderId}/status | Изменение статуса заказа
*OrdersApi* | [**update_order_statuses**](docs/OrdersApi.md#update_order_statuses) | **POST** /campaigns/{campaignId}/orders/status-update | Изменение статусов заказа
*OrdersStatsApi* | [**get_orders_stats**](docs/OrdersStatsApi.md#get_orders_stats) | **POST** /campaigns/{campaignId}/stats/orders | Детальная информация по заказам
*OutletLicensesApi* | [**delete_outlet_licenses**](docs/OutletLicensesApi.md#delete_outlet_licenses) | **DELETE** /campaigns/{campaignId}/outlets/licenses | Удаление лицензий для точек продаж
*OutletLicensesApi* | [**get_outlet_licenses**](docs/OutletLicensesApi.md#get_outlet_licenses) | **GET** /campaigns/{campaignId}/outlets/licenses | Информация о лицензиях для точек продаж
*OutletLicensesApi* | [**update_outlet_licenses**](docs/OutletLicensesApi.md#update_outlet_licenses) | **POST** /campaigns/{campaignId}/outlets/licenses | Создание и изменение лицензий для точек продаж
*OutletsApi* | [**create_outlet**](docs/OutletsApi.md#create_outlet) | **POST** /campaigns/{campaignId}/outlets | Создание точки продаж
*OutletsApi* | [**delete_outlet**](docs/OutletsApi.md#delete_outlet) | **DELETE** /campaigns/{campaignId}/outlets/{outletId} | Удаление точки продаж
*OutletsApi* | [**get_outlet**](docs/OutletsApi.md#get_outlet) | **GET** /campaigns/{campaignId}/outlets/{outletId} | Информация о точке продаж
*OutletsApi* | [**get_outlets**](docs/OutletsApi.md#get_outlets) | **GET** /campaigns/{campaignId}/outlets | Информация о точках продаж
*OutletsApi* | [**update_outlet**](docs/OutletsApi.md#update_outlet) | **PUT** /campaigns/{campaignId}/outlets/{outletId} | Изменение информации о точке продаж
*PriceQuarantineApi* | [**confirm_business_prices**](docs/PriceQuarantineApi.md#confirm_business_prices) | **POST** /businesses/{businessId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (основная цена)
*PriceQuarantineApi* | [**confirm_campaign_prices**](docs/PriceQuarantineApi.md#confirm_campaign_prices) | **POST** /campaigns/{campaignId}/price-quarantine/confirm | Подтверждение цены товара, попавшего в карантин (цена в магазине)
*PriceQuarantineApi* | [**get_business_quarantine_offers**](docs/PriceQuarantineApi.md#get_business_quarantine_offers) | **POST** /businesses/{businessId}/price-quarantine | Список товаров, находящихся в карантине (основная цена)
*PriceQuarantineApi* | [**get_campaign_quarantine_offers**](docs/PriceQuarantineApi.md#get_campaign_quarantine_offers) | **POST** /campaigns/{campaignId}/price-quarantine | Список товаров, находящихся в карантине (цена в магазине)
*PricesApi* | [**get_prices**](docs/PricesApi.md#get_prices) | **GET** /campaigns/{campaignId}/offer-prices | Список цен
*PricesApi* | [**get_prices_by_offer_ids**](docs/PricesApi.md#get_prices_by_offer_ids) | **POST** /campaigns/{campaignId}/offer-prices | Просмотр установленных в магазине цен
*PricesApi* | [**get_suggested_prices**](docs/PricesApi.md#get_suggested_prices) | **POST** /campaigns/{campaignId}/offer-prices/suggestions | Цены для продвижения товаров
*PricesApi* | [**update_business_prices**](docs/PricesApi.md#update_business_prices) | **POST** /businesses/{businessId}/offer-prices/updates | Установка цен
*PricesApi* | [**update_prices**](docs/PricesApi.md#update_prices) | **POST** /campaigns/{campaignId}/offer-prices/updates | Установка цен на товары в конкретном магазине
*RegionsApi* | [**search_region_children**](docs/RegionsApi.md#search_region_children) | **GET** /regions/{regionId}/children | Информация о дочерних регионах
*RegionsApi* | [**search_regions_by_id**](docs/RegionsApi.md#search_regions_by_id) | **GET** /regions/{regionId} | Информация о регионе
*RegionsApi* | [**search_regions_by_name**](docs/RegionsApi.md#search_regions_by_name) | **GET** /regions | Метод для поиска регионов по их имени
*ReportsApi* | [**generate_boost_consolidated_report**](docs/ReportsApi.md#generate_boost_consolidated_report) | **POST** /reports/boost-consolidated/generate | Отчет по бусту продаж
*ReportsApi* | [**generate_goods_movement_report**](docs/ReportsApi.md#generate_goods_movement_report) | **POST** /reports/goods-movement/generate | Отчет по движению товаров
*ReportsApi* | [**generate_goods_realization_report**](docs/ReportsApi.md#generate_goods_realization_report) | **POST** /reports/goods-realization/generate | Отчет по реализации
*ReportsApi* | [**generate_goods_turnover_report**](docs/ReportsApi.md#generate_goods_turnover_report) | **POST** /reports/goods-turnover/generate | Отчет по оборачиваемости
*ReportsApi* | [**generate_prices_report**](docs/ReportsApi.md#generate_prices_report) | **POST** /reports/prices/generate | Отчет «Цены на рынке»
*ReportsApi* | [**generate_shipment_list_document_report**](docs/ReportsApi.md#generate_shipment_list_document_report) | **POST** /reports/documents/shipment-list/generate | Лист сборки
*ReportsApi* | [**generate_shows_sales_report**](docs/ReportsApi.md#generate_shows_sales_report) | **POST** /reports/shows-sales/generate | Отчет «Аналитика продаж»
*ReportsApi* | [**generate_stocks_on_warehouses_report**](docs/ReportsApi.md#generate_stocks_on_warehouses_report) | **POST** /reports/stocks-on-warehouses/generate | Отчет по остаткам на складах
*ReportsApi* | [**generate_united_marketplace_services_report**](docs/ReportsApi.md#generate_united_marketplace_services_report) | **POST** /reports/united-marketplace-services/generate | Отчет по стоимости услуг
*ReportsApi* | [**generate_united_netting_report**](docs/ReportsApi.md#generate_united_netting_report) | **POST** /reports/united-netting/generate | Отчет по платежам
*ReportsApi* | [**generate_united_orders_report**](docs/ReportsApi.md#generate_united_orders_report) | **POST** /reports/united-orders/generate | Отчет по заказам
*ReportsApi* | [**get_report_info**](docs/ReportsApi.md#get_report_info) | **GET** /reports/info/{reportId} | Статус генерации и скачивание готовых отчетов
*ReturnsApi* | [**get_return**](docs/ReturnsApi.md#get_return) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId} | Информация о возврате или невыкупе
*ReturnsApi* | [**get_return_application**](docs/ReturnsApi.md#get_return_application) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/application | Получение заявления на возврат
*ReturnsApi* | [**get_return_photo**](docs/ReturnsApi.md#get_return_photo) | **GET** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/{itemId}/image/{imageHash} | Получение фотографии возврата
*ReturnsApi* | [**get_returns**](docs/ReturnsApi.md#get_returns) | **GET** /campaigns/{campaignId}/returns | Список возвратов и невыкупов
*ReturnsApi* | [**set_return_decision**](docs/ReturnsApi.md#set_return_decision) | **POST** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision | Принятие/изменение решения по позиции в возврате
*ReturnsApi* | [**submit_return_decision**](docs/ReturnsApi.md#submit_return_decision) | **POST** /campaigns/{campaignId}/orders/{orderId}/returns/{returnId}/decision/submit | Подтверждение решения по возвратным позициям
*ShipmentsApi* | [**confirm_shipment**](docs/ShipmentsApi.md#confirm_shipment) | **POST** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/confirm | Подтверждение отгрузки
*ShipmentsApi* | [**download_shipment_act**](docs/ShipmentsApi.md#download_shipment_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/act | Получение акта приема-передачи
*ShipmentsApi* | [**download_shipment_discrepancy_act**](docs/ShipmentsApi.md#download_shipment_discrepancy_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/discrepancy-act | Получение акта расхождений
*ShipmentsApi* | [**download_shipment_inbound_act**](docs/ShipmentsApi.md#download_shipment_inbound_act) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/inbound-act | Получение фактического акта приема-передачи
*ShipmentsApi* | [**download_shipment_pallet_labels**](docs/ShipmentsApi.md#download_shipment_pallet_labels) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/pallet/labels | Ярлыки на все упаковки в отгрузке
*ShipmentsApi* | [**download_shipment_reception_transfer_act**](docs/ShipmentsApi.md#download_shipment_reception_transfer_act) | **GET** /campaigns/{campaignId}/shipments/reception-transfer-act | Подтверждение ближайшей отгрузки и получение акта приема-передачи для нее
*ShipmentsApi* | [**download_shipment_transportation_waybill**](docs/ShipmentsApi.md#download_shipment_transportation_waybill) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/transportation-waybill | Получение транспортной накладной
*ShipmentsApi* | [**get_shipment**](docs/ShipmentsApi.md#get_shipment) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId} | Получение информации об отгрузке
*ShipmentsApi* | [**get_shipment_orders_info**](docs/ShipmentsApi.md#get_shipment_orders_info) | **GET** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/orders/info | Получение информации о ярлыках
*ShipmentsApi* | [**search_shipments**](docs/ShipmentsApi.md#search_shipments) | **PUT** /campaigns/{campaignId}/first-mile/shipments | Получение информации об отгрузках
*ShipmentsApi* | [**set_shipment_pallets_count**](docs/ShipmentsApi.md#set_shipment_pallets_count) | **PUT** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/pallets | Передача количества упаковок в отгрузке
*ShipmentsApi* | [**transfer_orders_from_shipment**](docs/ShipmentsApi.md#transfer_orders_from_shipment) | **POST** /campaigns/{campaignId}/first-mile/shipments/{shipmentId}/orders/transfer | Перенос заказов в следующую отгрузку
*StocksApi* | [**get_stocks**](docs/StocksApi.md#get_stocks) | **POST** /campaigns/{campaignId}/offers/stocks | Информация об остатках и оборачиваемости
*StocksApi* | [**update_stocks**](docs/StocksApi.md#update_stocks) | **PUT** /campaigns/{campaignId}/offers/stocks | Передача информации об остатках
*TariffsApi* | [**calculate_tariffs**](docs/TariffsApi.md#calculate_tariffs) | **POST** /tariffs/calculate | Калькулятор стоимости услуг
*WarehousesApi* | [**get_fulfillment_warehouses**](docs/WarehousesApi.md#get_fulfillment_warehouses) | **GET** /warehouses | Идентификаторы складов Маркета (FBY)
*WarehousesApi* | [**get_warehouses**](docs/WarehousesApi.md#get_warehouses) | **GET** /businesses/{businessId}/warehouses | Список складов и групп складов


## Documentation For Models

 - [AcceptOrderCancellationRequest](docs/AcceptOrderCancellationRequest.md)
 - [AddHiddenOffersRequest](docs/AddHiddenOffersRequest.md)
 - [AddOffersToArchiveDTO](docs/AddOffersToArchiveDTO.md)
 - [AddOffersToArchiveErrorDTO](docs/AddOffersToArchiveErrorDTO.md)
 - [AddOffersToArchiveErrorType](docs/AddOffersToArchiveErrorType.md)
 - [AddOffersToArchiveRequest](docs/AddOffersToArchiveRequest.md)
 - [AddOffersToArchiveResponse](docs/AddOffersToArchiveResponse.md)
 - [AgeDTO](docs/AgeDTO.md)
 - [AgeUnitType](docs/AgeUnitType.md)
 - [ApiClientDataErrorResponse](docs/ApiClientDataErrorResponse.md)
 - [ApiErrorDTO](docs/ApiErrorDTO.md)
 - [ApiErrorResponse](docs/ApiErrorResponse.md)
 - [ApiForbiddenErrorResponse](docs/ApiForbiddenErrorResponse.md)
 - [ApiLimitErrorResponse](docs/ApiLimitErrorResponse.md)
 - [ApiLockedErrorResponse](docs/ApiLockedErrorResponse.md)
 - [ApiNotFoundErrorResponse](docs/ApiNotFoundErrorResponse.md)
 - [ApiResponse](docs/ApiResponse.md)
 - [ApiResponseStatusType](docs/ApiResponseStatusType.md)
 - [ApiServerErrorResponse](docs/ApiServerErrorResponse.md)
 - [ApiUnauthorizedErrorResponse](docs/ApiUnauthorizedErrorResponse.md)
 - [BaseCampaignOfferDTO](docs/BaseCampaignOfferDTO.md)
 - [BaseOfferDTO](docs/BaseOfferDTO.md)
 - [BasePriceDTO](docs/BasePriceDTO.md)
 - [BidRecommendationItemDTO](docs/BidRecommendationItemDTO.md)
 - [BriefOrderItemDTO](docs/BriefOrderItemDTO.md)
 - [BriefOrderItemInstanceDTO](docs/BriefOrderItemInstanceDTO.md)
 - [BusinessDTO](docs/BusinessDTO.md)
 - [CalculateTariffsOfferDTO](docs/CalculateTariffsOfferDTO.md)
 - [CalculateTariffsOfferInfoDTO](docs/CalculateTariffsOfferInfoDTO.md)
 - [CalculateTariffsParametersDTO](docs/CalculateTariffsParametersDTO.md)
 - [CalculateTariffsRequest](docs/CalculateTariffsRequest.md)
 - [CalculateTariffsResponse](docs/CalculateTariffsResponse.md)
 - [CalculateTariffsResponseDTO](docs/CalculateTariffsResponseDTO.md)
 - [CalculatedTariffDTO](docs/CalculatedTariffDTO.md)
 - [CalculatedTariffType](docs/CalculatedTariffType.md)
 - [CampaignDTO](docs/CampaignDTO.md)
 - [CampaignSettingsDTO](docs/CampaignSettingsDTO.md)
 - [CampaignSettingsDeliveryDTO](docs/CampaignSettingsDeliveryDTO.md)
 - [CampaignSettingsLocalRegionDTO](docs/CampaignSettingsLocalRegionDTO.md)
 - [CampaignSettingsScheduleDTO](docs/CampaignSettingsScheduleDTO.md)
 - [CampaignSettingsScheduleSourceType](docs/CampaignSettingsScheduleSourceType.md)
 - [CampaignSettingsTimePeriodDTO](docs/CampaignSettingsTimePeriodDTO.md)
 - [CategoryContentParametersDTO](docs/CategoryContentParametersDTO.md)
 - [CategoryDTO](docs/CategoryDTO.md)
 - [CategoryParameterDTO](docs/CategoryParameterDTO.md)
 - [CategoryParameterUnitDTO](docs/CategoryParameterUnitDTO.md)
 - [ChangeOutletRequest](docs/ChangeOutletRequest.md)
 - [ChatMessageDTO](docs/ChatMessageDTO.md)
 - [ChatMessagePayloadDTO](docs/ChatMessagePayloadDTO.md)
 - [ChatMessageSenderType](docs/ChatMessageSenderType.md)
 - [ChatMessagesResultDTO](docs/ChatMessagesResultDTO.md)
 - [ChatStatusType](docs/ChatStatusType.md)
 - [ChatType](docs/ChatType.md)
 - [ConfirmPricesRequest](docs/ConfirmPricesRequest.md)
 - [ConfirmShipmentRequest](docs/ConfirmShipmentRequest.md)
 - [CreateChatRequest](docs/CreateChatRequest.md)
 - [CreateChatResponse](docs/CreateChatResponse.md)
 - [CreateChatResultDTO](docs/CreateChatResultDTO.md)
 - [CreateOutletResponse](docs/CreateOutletResponse.md)
 - [CurrencyType](docs/CurrencyType.md)
 - [DayOfWeekType](docs/DayOfWeekType.md)
 - [DeleteCampaignOffersDTO](docs/DeleteCampaignOffersDTO.md)
 - [DeleteCampaignOffersRequest](docs/DeleteCampaignOffersRequest.md)
 - [DeleteCampaignOffersResponse](docs/DeleteCampaignOffersResponse.md)
 - [DeleteHiddenOffersRequest](docs/DeleteHiddenOffersRequest.md)
 - [DeleteOffersDTO](docs/DeleteOffersDTO.md)
 - [DeleteOffersFromArchiveDTO](docs/DeleteOffersFromArchiveDTO.md)
 - [DeleteOffersFromArchiveRequest](docs/DeleteOffersFromArchiveRequest.md)
 - [DeleteOffersFromArchiveResponse](docs/DeleteOffersFromArchiveResponse.md)
 - [DeleteOffersRequest](docs/DeleteOffersRequest.md)
 - [DeleteOffersResponse](docs/DeleteOffersResponse.md)
 - [DeliveryServiceDTO](docs/DeliveryServiceDTO.md)
 - [DeliveryServiceInfoDTO](docs/DeliveryServiceInfoDTO.md)
 - [DeliveryServicesDTO](docs/DeliveryServicesDTO.md)
 - [DocumentDTO](docs/DocumentDTO.md)
 - [EacVerificationResultDTO](docs/EacVerificationResultDTO.md)
 - [EacVerificationStatusType](docs/EacVerificationStatusType.md)
 - [EmptyApiResponse](docs/EmptyApiResponse.md)
 - [EnrichedMappingsOfferDTO](docs/EnrichedMappingsOfferDTO.md)
 - [EnrichedModelDTO](docs/EnrichedModelDTO.md)
 - [EnrichedOrderBoxLayoutDTO](docs/EnrichedOrderBoxLayoutDTO.md)
 - [FeedCategoryDTO](docs/FeedCategoryDTO.md)
 - [FeedContentDTO](docs/FeedContentDTO.md)
 - [FeedContentErrorDTO](docs/FeedContentErrorDTO.md)
 - [FeedContentErrorType](docs/FeedContentErrorType.md)
 - [FeedDTO](docs/FeedDTO.md)
 - [FeedDownloadDTO](docs/FeedDownloadDTO.md)
 - [FeedDownloadErrorDTO](docs/FeedDownloadErrorDTO.md)
 - [FeedDownloadErrorType](docs/FeedDownloadErrorType.md)
 - [FeedIndexLogsErrorDTO](docs/FeedIndexLogsErrorDTO.md)
 - [FeedIndexLogsErrorType](docs/FeedIndexLogsErrorType.md)
 - [FeedIndexLogsFeedDTO](docs/FeedIndexLogsFeedDTO.md)
 - [FeedIndexLogsIndexType](docs/FeedIndexLogsIndexType.md)
 - [FeedIndexLogsOffersDTO](docs/FeedIndexLogsOffersDTO.md)
 - [FeedIndexLogsRecordDTO](docs/FeedIndexLogsRecordDTO.md)
 - [FeedIndexLogsResultDTO](docs/FeedIndexLogsResultDTO.md)
 - [FeedIndexLogsStatusType](docs/FeedIndexLogsStatusType.md)
 - [FeedParameterDTO](docs/FeedParameterDTO.md)
 - [FeedPlacementDTO](docs/FeedPlacementDTO.md)
 - [FeedPublicationDTO](docs/FeedPublicationDTO.md)
 - [FeedPublicationFullDTO](docs/FeedPublicationFullDTO.md)
 - [FeedPublicationPriceAndStockUpdateDTO](docs/FeedPublicationPriceAndStockUpdateDTO.md)
 - [FeedStatusType](docs/FeedStatusType.md)
 - [FeedbackAuthorDTO](docs/FeedbackAuthorDTO.md)
 - [FeedbackCommentAuthorDTO](docs/FeedbackCommentAuthorDTO.md)
 - [FeedbackCommentAuthorType](docs/FeedbackCommentAuthorType.md)
 - [FeedbackCommentDTO](docs/FeedbackCommentDTO.md)
 - [FeedbackDTO](docs/FeedbackDTO.md)
 - [FeedbackDeliveryType](docs/FeedbackDeliveryType.md)
 - [FeedbackFactorDTO](docs/FeedbackFactorDTO.md)
 - [FeedbackGradesDTO](docs/FeedbackGradesDTO.md)
 - [FeedbackListDTO](docs/FeedbackListDTO.md)
 - [FeedbackOrderDTO](docs/FeedbackOrderDTO.md)
 - [FeedbackShopDTO](docs/FeedbackShopDTO.md)
 - [FeedbackStateType](docs/FeedbackStateType.md)
 - [FieldStateType](docs/FieldStateType.md)
 - [FlippingPagerDTO](docs/FlippingPagerDTO.md)
 - [ForwardScrollingPagerDTO](docs/ForwardScrollingPagerDTO.md)
 - [FulfillmentWarehouseDTO](docs/FulfillmentWarehouseDTO.md)
 - [FulfillmentWarehousesDTO](docs/FulfillmentWarehousesDTO.md)
 - [FullOutletDTO](docs/FullOutletDTO.md)
 - [FullOutletLicenseDTO](docs/FullOutletLicenseDTO.md)
 - [GenerateBoostConsolidatedRequest](docs/GenerateBoostConsolidatedRequest.md)
 - [GenerateGoodsMovementReportRequest](docs/GenerateGoodsMovementReportRequest.md)
 - [GenerateGoodsRealizationReportRequest](docs/GenerateGoodsRealizationReportRequest.md)
 - [GenerateGoodsTurnoverRequest](docs/GenerateGoodsTurnoverRequest.md)
 - [GeneratePricesReportRequest](docs/GeneratePricesReportRequest.md)
 - [GenerateReportDTO](docs/GenerateReportDTO.md)
 - [GenerateReportResponse](docs/GenerateReportResponse.md)
 - [GenerateShipmentListDocumentReportRequest](docs/GenerateShipmentListDocumentReportRequest.md)
 - [GenerateShowsSalesReportRequest](docs/GenerateShowsSalesReportRequest.md)
 - [GenerateStocksOnWarehousesReportRequest](docs/GenerateStocksOnWarehousesReportRequest.md)
 - [GenerateUnitedMarketplaceServicesReportRequest](docs/GenerateUnitedMarketplaceServicesReportRequest.md)
 - [GenerateUnitedNettingReportRequest](docs/GenerateUnitedNettingReportRequest.md)
 - [GenerateUnitedOrdersRequest](docs/GenerateUnitedOrdersRequest.md)
 - [GetAllOffersResponse](docs/GetAllOffersResponse.md)
 - [GetBidsInfoRequest](docs/GetBidsInfoRequest.md)
 - [GetBidsInfoResponse](docs/GetBidsInfoResponse.md)
 - [GetBidsInfoResponseDTO](docs/GetBidsInfoResponseDTO.md)
 - [GetBidsRecommendationsRequest](docs/GetBidsRecommendationsRequest.md)
 - [GetBidsRecommendationsResponse](docs/GetBidsRecommendationsResponse.md)
 - [GetBidsRecommendationsResponseDTO](docs/GetBidsRecommendationsResponseDTO.md)
 - [GetBusinessBuyerInfoResponse](docs/GetBusinessBuyerInfoResponse.md)
 - [GetBusinessDocumentsInfoResponse](docs/GetBusinessDocumentsInfoResponse.md)
 - [GetCampaignCategoriesResponse](docs/GetCampaignCategoriesResponse.md)
 - [GetCampaignLoginsResponse](docs/GetCampaignLoginsResponse.md)
 - [GetCampaignOfferDTO](docs/GetCampaignOfferDTO.md)
 - [GetCampaignOffersRequest](docs/GetCampaignOffersRequest.md)
 - [GetCampaignOffersResponse](docs/GetCampaignOffersResponse.md)
 - [GetCampaignOffersResultDTO](docs/GetCampaignOffersResultDTO.md)
 - [GetCampaignRegionResponse](docs/GetCampaignRegionResponse.md)
 - [GetCampaignResponse](docs/GetCampaignResponse.md)
 - [GetCampaignSettingsResponse](docs/GetCampaignSettingsResponse.md)
 - [GetCampaignsResponse](docs/GetCampaignsResponse.md)
 - [GetCategoriesResponse](docs/GetCategoriesResponse.md)
 - [GetCategoryContentParametersResponse](docs/GetCategoryContentParametersResponse.md)
 - [GetChatHistoryRequest](docs/GetChatHistoryRequest.md)
 - [GetChatHistoryResponse](docs/GetChatHistoryResponse.md)
 - [GetChatInfoDTO](docs/GetChatInfoDTO.md)
 - [GetChatsInfoDTO](docs/GetChatsInfoDTO.md)
 - [GetChatsRequest](docs/GetChatsRequest.md)
 - [GetChatsResponse](docs/GetChatsResponse.md)
 - [GetDeliveryServicesResponse](docs/GetDeliveryServicesResponse.md)
 - [GetFeedCategoriesResponse](docs/GetFeedCategoriesResponse.md)
 - [GetFeedIndexLogsResponse](docs/GetFeedIndexLogsResponse.md)
 - [GetFeedResponse](docs/GetFeedResponse.md)
 - [GetFeedbackListResponse](docs/GetFeedbackListResponse.md)
 - [GetFeedsResponse](docs/GetFeedsResponse.md)
 - [GetFulfillmentWarehousesResponse](docs/GetFulfillmentWarehousesResponse.md)
 - [GetGoodsStatsRequest](docs/GetGoodsStatsRequest.md)
 - [GetGoodsStatsResponse](docs/GetGoodsStatsResponse.md)
 - [GetHiddenOffersResponse](docs/GetHiddenOffersResponse.md)
 - [GetHiddenOffersResultDTO](docs/GetHiddenOffersResultDTO.md)
 - [GetMappingDTO](docs/GetMappingDTO.md)
 - [GetModelsOffersResponse](docs/GetModelsOffersResponse.md)
 - [GetModelsRequest](docs/GetModelsRequest.md)
 - [GetModelsResponse](docs/GetModelsResponse.md)
 - [GetOfferCardsContentStatusRequest](docs/GetOfferCardsContentStatusRequest.md)
 - [GetOfferCardsContentStatusResponse](docs/GetOfferCardsContentStatusResponse.md)
 - [GetOfferDTO](docs/GetOfferDTO.md)
 - [GetOfferMappingDTO](docs/GetOfferMappingDTO.md)
 - [GetOfferMappingEntriesResponse](docs/GetOfferMappingEntriesResponse.md)
 - [GetOfferMappingsRequest](docs/GetOfferMappingsRequest.md)
 - [GetOfferMappingsResponse](docs/GetOfferMappingsResponse.md)
 - [GetOfferMappingsResultDTO](docs/GetOfferMappingsResultDTO.md)
 - [GetOfferRecommendationsRequest](docs/GetOfferRecommendationsRequest.md)
 - [GetOfferRecommendationsResponse](docs/GetOfferRecommendationsResponse.md)
 - [GetOffersResponse](docs/GetOffersResponse.md)
 - [GetOrderBuyerInfoResponse](docs/GetOrderBuyerInfoResponse.md)
 - [GetOrderLabelsDataResponse](docs/GetOrderLabelsDataResponse.md)
 - [GetOrderResponse](docs/GetOrderResponse.md)
 - [GetOrdersResponse](docs/GetOrdersResponse.md)
 - [GetOrdersStatsRequest](docs/GetOrdersStatsRequest.md)
 - [GetOrdersStatsResponse](docs/GetOrdersStatsResponse.md)
 - [GetOutletLicensesResponse](docs/GetOutletLicensesResponse.md)
 - [GetOutletResponse](docs/GetOutletResponse.md)
 - [GetOutletsResponse](docs/GetOutletsResponse.md)
 - [GetPriceDTO](docs/GetPriceDTO.md)
 - [GetPriceWithDiscountDTO](docs/GetPriceWithDiscountDTO.md)
 - [GetPriceWithVatDTO](docs/GetPriceWithVatDTO.md)
 - [GetPricesByOfferIdsRequest](docs/GetPricesByOfferIdsRequest.md)
 - [GetPricesByOfferIdsResponse](docs/GetPricesByOfferIdsResponse.md)
 - [GetPricesResponse](docs/GetPricesResponse.md)
 - [GetQuarantineOffersRequest](docs/GetQuarantineOffersRequest.md)
 - [GetQuarantineOffersResponse](docs/GetQuarantineOffersResponse.md)
 - [GetQuarantineOffersResultDTO](docs/GetQuarantineOffersResultDTO.md)
 - [GetRegionWithChildrenResponse](docs/GetRegionWithChildrenResponse.md)
 - [GetRegionsResponse](docs/GetRegionsResponse.md)
 - [GetReportInfoResponse](docs/GetReportInfoResponse.md)
 - [GetReturnResponse](docs/GetReturnResponse.md)
 - [GetReturnsResponse](docs/GetReturnsResponse.md)
 - [GetShipmentOrdersInfoResponse](docs/GetShipmentOrdersInfoResponse.md)
 - [GetShipmentResponse](docs/GetShipmentResponse.md)
 - [GetSuggestedOfferMappingEntriesRequest](docs/GetSuggestedOfferMappingEntriesRequest.md)
 - [GetSuggestedOfferMappingEntriesResponse](docs/GetSuggestedOfferMappingEntriesResponse.md)
 - [GetSuggestedOfferMappingsRequest](docs/GetSuggestedOfferMappingsRequest.md)
 - [GetSuggestedOfferMappingsResponse](docs/GetSuggestedOfferMappingsResponse.md)
 - [GetSuggestedOfferMappingsResultDTO](docs/GetSuggestedOfferMappingsResultDTO.md)
 - [GetWarehouseStocksDTO](docs/GetWarehouseStocksDTO.md)
 - [GetWarehouseStocksRequest](docs/GetWarehouseStocksRequest.md)
 - [GetWarehouseStocksResponse](docs/GetWarehouseStocksResponse.md)
 - [GetWarehousesResponse](docs/GetWarehousesResponse.md)
 - [GoodsStatsDTO](docs/GoodsStatsDTO.md)
 - [GoodsStatsGoodsDTO](docs/GoodsStatsGoodsDTO.md)
 - [GoodsStatsWarehouseDTO](docs/GoodsStatsWarehouseDTO.md)
 - [GoodsStatsWeightDimensionsDTO](docs/GoodsStatsWeightDimensionsDTO.md)
 - [GpsDTO](docs/GpsDTO.md)
 - [HiddenOfferDTO](docs/HiddenOfferDTO.md)
 - [LicenseCheckStatusType](docs/LicenseCheckStatusType.md)
 - [LicenseType](docs/LicenseType.md)
 - [LogisticPickupPointDTO](docs/LogisticPickupPointDTO.md)
 - [LogisticPointType](docs/LogisticPointType.md)
 - [MappingsOfferDTO](docs/MappingsOfferDTO.md)
 - [MappingsOfferInfoDTO](docs/MappingsOfferInfoDTO.md)
 - [ModelDTO](docs/ModelDTO.md)
 - [ModelOfferDTO](docs/ModelOfferDTO.md)
 - [ModelPriceDTO](docs/ModelPriceDTO.md)
 - [OfferAvailabilityStatusType](docs/OfferAvailabilityStatusType.md)
 - [OfferCampaignStatusDTO](docs/OfferCampaignStatusDTO.md)
 - [OfferCampaignStatusType](docs/OfferCampaignStatusType.md)
 - [OfferCardDTO](docs/OfferCardDTO.md)
 - [OfferCardRecommendationDTO](docs/OfferCardRecommendationDTO.md)
 - [OfferCardRecommendationType](docs/OfferCardRecommendationType.md)
 - [OfferCardStatusType](docs/OfferCardStatusType.md)
 - [OfferCardsContentStatusDTO](docs/OfferCardsContentStatusDTO.md)
 - [OfferConditionDTO](docs/OfferConditionDTO.md)
 - [OfferConditionQualityType](docs/OfferConditionQualityType.md)
 - [OfferConditionType](docs/OfferConditionType.md)
 - [OfferContentDTO](docs/OfferContentDTO.md)
 - [OfferContentErrorDTO](docs/OfferContentErrorDTO.md)
 - [OfferContentErrorType](docs/OfferContentErrorType.md)
 - [OfferDTO](docs/OfferDTO.md)
 - [OfferErrorDTO](docs/OfferErrorDTO.md)
 - [OfferForRecommendationDTO](docs/OfferForRecommendationDTO.md)
 - [OfferManualDTO](docs/OfferManualDTO.md)
 - [OfferMappingDTO](docs/OfferMappingDTO.md)
 - [OfferMappingEntriesDTO](docs/OfferMappingEntriesDTO.md)
 - [OfferMappingEntryDTO](docs/OfferMappingEntryDTO.md)
 - [OfferMappingInfoDTO](docs/OfferMappingInfoDTO.md)
 - [OfferMappingKindType](docs/OfferMappingKindType.md)
 - [OfferMappingSuggestionsListDTO](docs/OfferMappingSuggestionsListDTO.md)
 - [OfferParamDTO](docs/OfferParamDTO.md)
 - [OfferPriceByOfferIdsListResponseDTO](docs/OfferPriceByOfferIdsListResponseDTO.md)
 - [OfferPriceByOfferIdsResponseDTO](docs/OfferPriceByOfferIdsResponseDTO.md)
 - [OfferPriceDTO](docs/OfferPriceDTO.md)
 - [OfferPriceFeedDTO](docs/OfferPriceFeedDTO.md)
 - [OfferPriceListResponseDTO](docs/OfferPriceListResponseDTO.md)
 - [OfferPriceResponseDTO](docs/OfferPriceResponseDTO.md)
 - [OfferProcessingNoteDTO](docs/OfferProcessingNoteDTO.md)
 - [OfferProcessingNoteType](docs/OfferProcessingNoteType.md)
 - [OfferProcessingStateDTO](docs/OfferProcessingStateDTO.md)
 - [OfferProcessingStatusType](docs/OfferProcessingStatusType.md)
 - [OfferRecommendationDTO](docs/OfferRecommendationDTO.md)
 - [OfferRecommendationInfoDTO](docs/OfferRecommendationInfoDTO.md)
 - [OfferRecommendationsResultDTO](docs/OfferRecommendationsResultDTO.md)
 - [OfferSellingProgramDTO](docs/OfferSellingProgramDTO.md)
 - [OfferSellingProgramStatusType](docs/OfferSellingProgramStatusType.md)
 - [OfferType](docs/OfferType.md)
 - [OfferWeightDimensionsDTO](docs/OfferWeightDimensionsDTO.md)
 - [OffersDTO](docs/OffersDTO.md)
 - [OptionValuesLimitedDTO](docs/OptionValuesLimitedDTO.md)
 - [OrderBoxLayoutDTO](docs/OrderBoxLayoutDTO.md)
 - [OrderBoxLayoutItemDTO](docs/OrderBoxLayoutItemDTO.md)
 - [OrderBoxLayoutPartialCountDTO](docs/OrderBoxLayoutPartialCountDTO.md)
 - [OrderBoxesLayoutDTO](docs/OrderBoxesLayoutDTO.md)
 - [OrderBusinessBuyerDTO](docs/OrderBusinessBuyerDTO.md)
 - [OrderBusinessDocumentsDTO](docs/OrderBusinessDocumentsDTO.md)
 - [OrderBuyerBasicInfoDTO](docs/OrderBuyerBasicInfoDTO.md)
 - [OrderBuyerDTO](docs/OrderBuyerDTO.md)
 - [OrderBuyerInfoDTO](docs/OrderBuyerInfoDTO.md)
 - [OrderBuyerType](docs/OrderBuyerType.md)
 - [OrderCancellationReasonType](docs/OrderCancellationReasonType.md)
 - [OrderCourierDTO](docs/OrderCourierDTO.md)
 - [OrderDTO](docs/OrderDTO.md)
 - [OrderDeliveryAddressDTO](docs/OrderDeliveryAddressDTO.md)
 - [OrderDeliveryDTO](docs/OrderDeliveryDTO.md)
 - [OrderDeliveryDateDTO](docs/OrderDeliveryDateDTO.md)
 - [OrderDeliveryDateReasonType](docs/OrderDeliveryDateReasonType.md)
 - [OrderDeliveryDatesDTO](docs/OrderDeliveryDatesDTO.md)
 - [OrderDeliveryDispatchType](docs/OrderDeliveryDispatchType.md)
 - [OrderDeliveryEacType](docs/OrderDeliveryEacType.md)
 - [OrderDeliveryPartnerType](docs/OrderDeliveryPartnerType.md)
 - [OrderDeliveryType](docs/OrderDeliveryType.md)
 - [OrderDigitalItemDTO](docs/OrderDigitalItemDTO.md)
 - [OrderDocumentStatusType](docs/OrderDocumentStatusType.md)
 - [OrderItemDTO](docs/OrderItemDTO.md)
 - [OrderItemDetailDTO](docs/OrderItemDetailDTO.md)
 - [OrderItemInstanceDTO](docs/OrderItemInstanceDTO.md)
 - [OrderItemInstanceModificationDTO](docs/OrderItemInstanceModificationDTO.md)
 - [OrderItemInstanceType](docs/OrderItemInstanceType.md)
 - [OrderItemModificationDTO](docs/OrderItemModificationDTO.md)
 - [OrderItemPromoDTO](docs/OrderItemPromoDTO.md)
 - [OrderItemStatusType](docs/OrderItemStatusType.md)
 - [OrderItemSubsidyDTO](docs/OrderItemSubsidyDTO.md)
 - [OrderItemsModificationRequestReasonType](docs/OrderItemsModificationRequestReasonType.md)
 - [OrderItemsModificationResultDTO](docs/OrderItemsModificationResultDTO.md)
 - [OrderLabelDTO](docs/OrderLabelDTO.md)
 - [OrderLiftType](docs/OrderLiftType.md)
 - [OrderParcelBoxDTO](docs/OrderParcelBoxDTO.md)
 - [OrderParcelStatusType](docs/OrderParcelStatusType.md)
 - [OrderPaymentMethodType](docs/OrderPaymentMethodType.md)
 - [OrderPaymentType](docs/OrderPaymentType.md)
 - [OrderPromoType](docs/OrderPromoType.md)
 - [OrderShipmentDTO](docs/OrderShipmentDTO.md)
 - [OrderStateDTO](docs/OrderStateDTO.md)
 - [OrderStatsStatusType](docs/OrderStatsStatusType.md)
 - [OrderStatusChangeDTO](docs/OrderStatusChangeDTO.md)
 - [OrderStatusChangeDeliveryDTO](docs/OrderStatusChangeDeliveryDTO.md)
 - [OrderStatusChangeDeliveryDatesDTO](docs/OrderStatusChangeDeliveryDatesDTO.md)
 - [OrderStatusType](docs/OrderStatusType.md)
 - [OrderSubsidyType](docs/OrderSubsidyType.md)
 - [OrderSubstatusType](docs/OrderSubstatusType.md)
 - [OrderTaxSystemType](docs/OrderTaxSystemType.md)
 - [OrderTrackDTO](docs/OrderTrackDTO.md)
 - [OrderUpdateStatusType](docs/OrderUpdateStatusType.md)
 - [OrderVatType](docs/OrderVatType.md)
 - [OrdersShipmentInfoDTO](docs/OrdersShipmentInfoDTO.md)
 - [OrdersStatsCommissionDTO](docs/OrdersStatsCommissionDTO.md)
 - [OrdersStatsCommissionType](docs/OrdersStatsCommissionType.md)
 - [OrdersStatsDTO](docs/OrdersStatsDTO.md)
 - [OrdersStatsDeliveryRegionDTO](docs/OrdersStatsDeliveryRegionDTO.md)
 - [OrdersStatsDetailsDTO](docs/OrdersStatsDetailsDTO.md)
 - [OrdersStatsItemDTO](docs/OrdersStatsItemDTO.md)
 - [OrdersStatsItemStatusType](docs/OrdersStatsItemStatusType.md)
 - [OrdersStatsOrderDTO](docs/OrdersStatsOrderDTO.md)
 - [OrdersStatsOrderPaymentType](docs/OrdersStatsOrderPaymentType.md)
 - [OrdersStatsPaymentDTO](docs/OrdersStatsPaymentDTO.md)
 - [OrdersStatsPaymentOrderDTO](docs/OrdersStatsPaymentOrderDTO.md)
 - [OrdersStatsPaymentSourceType](docs/OrdersStatsPaymentSourceType.md)
 - [OrdersStatsPaymentType](docs/OrdersStatsPaymentType.md)
 - [OrdersStatsPriceDTO](docs/OrdersStatsPriceDTO.md)
 - [OrdersStatsPriceType](docs/OrdersStatsPriceType.md)
 - [OrdersStatsStockType](docs/OrdersStatsStockType.md)
 - [OrdersStatsWarehouseDTO](docs/OrdersStatsWarehouseDTO.md)
 - [OutletAddressDTO](docs/OutletAddressDTO.md)
 - [OutletDTO](docs/OutletDTO.md)
 - [OutletDeliveryRuleDTO](docs/OutletDeliveryRuleDTO.md)
 - [OutletLicenseDTO](docs/OutletLicenseDTO.md)
 - [OutletLicensesResponseDTO](docs/OutletLicensesResponseDTO.md)
 - [OutletResponseDTO](docs/OutletResponseDTO.md)
 - [OutletStatusType](docs/OutletStatusType.md)
 - [OutletType](docs/OutletType.md)
 - [OutletVisibilityType](docs/OutletVisibilityType.md)
 - [OutletWorkingScheduleDTO](docs/OutletWorkingScheduleDTO.md)
 - [OutletWorkingScheduleItemDTO](docs/OutletWorkingScheduleItemDTO.md)
 - [PageFormatType](docs/PageFormatType.md)
 - [PagedReturnsDTO](docs/PagedReturnsDTO.md)
 - [PalletsCountDTO](docs/PalletsCountDTO.md)
 - [ParameterType](docs/ParameterType.md)
 - [ParameterValueConstraintsDTO](docs/ParameterValueConstraintsDTO.md)
 - [ParameterValueDTO](docs/ParameterValueDTO.md)
 - [ParameterValueOptionDTO](docs/ParameterValueOptionDTO.md)
 - [ParcelBoxDTO](docs/ParcelBoxDTO.md)
 - [ParcelBoxLabelDTO](docs/ParcelBoxLabelDTO.md)
 - [ParcelDTO](docs/ParcelDTO.md)
 - [PartnerShipmentWarehouseDTO](docs/PartnerShipmentWarehouseDTO.md)
 - [PaymentFrequencyType](docs/PaymentFrequencyType.md)
 - [PickupAddressDTO](docs/PickupAddressDTO.md)
 - [PlacementType](docs/PlacementType.md)
 - [PriceCompetitivenessThresholdsDTO](docs/PriceCompetitivenessThresholdsDTO.md)
 - [PriceCompetitivenessType](docs/PriceCompetitivenessType.md)
 - [PriceDTO](docs/PriceDTO.md)
 - [PriceQuarantineVerdictDTO](docs/PriceQuarantineVerdictDTO.md)
 - [PriceQuarantineVerdictParamNameType](docs/PriceQuarantineVerdictParamNameType.md)
 - [PriceQuarantineVerdictParameterDTO](docs/PriceQuarantineVerdictParameterDTO.md)
 - [PriceQuarantineVerdictType](docs/PriceQuarantineVerdictType.md)
 - [PriceRecommendationItemDTO](docs/PriceRecommendationItemDTO.md)
 - [PriceSuggestDTO](docs/PriceSuggestDTO.md)
 - [PriceSuggestOfferDTO](docs/PriceSuggestOfferDTO.md)
 - [PriceSuggestType](docs/PriceSuggestType.md)
 - [ProvideOrderDigitalCodesRequest](docs/ProvideOrderDigitalCodesRequest.md)
 - [ProvideOrderItemIdentifiersRequest](docs/ProvideOrderItemIdentifiersRequest.md)
 - [ProvideOrderItemIdentifiersResponse](docs/ProvideOrderItemIdentifiersResponse.md)
 - [PutSkuBidsRequest](docs/PutSkuBidsRequest.md)
 - [QuantumDTO](docs/QuantumDTO.md)
 - [QuarantineOfferDTO](docs/QuarantineOfferDTO.md)
 - [RecipientType](docs/RecipientType.md)
 - [RefundStatusType](docs/RefundStatusType.md)
 - [RegionDTO](docs/RegionDTO.md)
 - [RegionType](docs/RegionType.md)
 - [RegionalModelInfoDTO](docs/RegionalModelInfoDTO.md)
 - [ReportFormatType](docs/ReportFormatType.md)
 - [ReportInfoDTO](docs/ReportInfoDTO.md)
 - [ReportStatusType](docs/ReportStatusType.md)
 - [ReportSubStatusType](docs/ReportSubStatusType.md)
 - [ReturnDTO](docs/ReturnDTO.md)
 - [ReturnDecisionDTO](docs/ReturnDecisionDTO.md)
 - [ReturnDecisionReasonType](docs/ReturnDecisionReasonType.md)
 - [ReturnDecisionSubreasonType](docs/ReturnDecisionSubreasonType.md)
 - [ReturnDecisionType](docs/ReturnDecisionType.md)
 - [ReturnInstanceDTO](docs/ReturnInstanceDTO.md)
 - [ReturnInstanceStatusType](docs/ReturnInstanceStatusType.md)
 - [ReturnInstanceStockType](docs/ReturnInstanceStockType.md)
 - [ReturnItemDTO](docs/ReturnItemDTO.md)
 - [ReturnRequestDecisionType](docs/ReturnRequestDecisionType.md)
 - [ReturnShipmentStatusType](docs/ReturnShipmentStatusType.md)
 - [ReturnType](docs/ReturnType.md)
 - [ScrollingPagerDTO](docs/ScrollingPagerDTO.md)
 - [SearchModelsResponse](docs/SearchModelsResponse.md)
 - [SearchShipmentsRequest](docs/SearchShipmentsRequest.md)
 - [SearchShipmentsResponse](docs/SearchShipmentsResponse.md)
 - [SearchShipmentsResponseDTO](docs/SearchShipmentsResponseDTO.md)
 - [SellingProgramType](docs/SellingProgramType.md)
 - [SendMessageToChatRequest](docs/SendMessageToChatRequest.md)
 - [SetFeedParamsRequest](docs/SetFeedParamsRequest.md)
 - [SetOrderBoxLayoutRequest](docs/SetOrderBoxLayoutRequest.md)
 - [SetOrderBoxLayoutResponse](docs/SetOrderBoxLayoutResponse.md)
 - [SetOrderDeliveryDateRequest](docs/SetOrderDeliveryDateRequest.md)
 - [SetOrderDeliveryTrackCodeRequest](docs/SetOrderDeliveryTrackCodeRequest.md)
 - [SetOrderShipmentBoxesRequest](docs/SetOrderShipmentBoxesRequest.md)
 - [SetOrderShipmentBoxesResponse](docs/SetOrderShipmentBoxesResponse.md)
 - [SetReturnDecisionRequest](docs/SetReturnDecisionRequest.md)
 - [SetShipmentPalletsCountRequest](docs/SetShipmentPalletsCountRequest.md)
 - [ShipmentActionType](docs/ShipmentActionType.md)
 - [ShipmentBoxesDTO](docs/ShipmentBoxesDTO.md)
 - [ShipmentDTO](docs/ShipmentDTO.md)
 - [ShipmentInfoDTO](docs/ShipmentInfoDTO.md)
 - [ShipmentPalletLabelPageFormatType](docs/ShipmentPalletLabelPageFormatType.md)
 - [ShipmentStatusChangeDTO](docs/ShipmentStatusChangeDTO.md)
 - [ShipmentStatusType](docs/ShipmentStatusType.md)
 - [ShipmentType](docs/ShipmentType.md)
 - [ShowsSalesGroupingType](docs/ShowsSalesGroupingType.md)
 - [SkuBidItemDTO](docs/SkuBidItemDTO.md)
 - [SkuBidRecommendationItemDTO](docs/SkuBidRecommendationItemDTO.md)
 - [SortOrderType](docs/SortOrderType.md)
 - [SuggestOfferPriceDTO](docs/SuggestOfferPriceDTO.md)
 - [SuggestPricesRequest](docs/SuggestPricesRequest.md)
 - [SuggestPricesResponse](docs/SuggestPricesResponse.md)
 - [SuggestPricesResultDTO](docs/SuggestPricesResultDTO.md)
 - [SuggestedOfferDTO](docs/SuggestedOfferDTO.md)
 - [SuggestedOfferMappingDTO](docs/SuggestedOfferMappingDTO.md)
 - [TariffDTO](docs/TariffDTO.md)
 - [TariffParameterDTO](docs/TariffParameterDTO.md)
 - [TariffType](docs/TariffType.md)
 - [TimePeriodDTO](docs/TimePeriodDTO.md)
 - [TimeUnitType](docs/TimeUnitType.md)
 - [TrackDTO](docs/TrackDTO.md)
 - [TransferOrdersFromShipmentRequest](docs/TransferOrdersFromShipmentRequest.md)
 - [TurnoverDTO](docs/TurnoverDTO.md)
 - [TurnoverType](docs/TurnoverType.md)
 - [UnitDTO](docs/UnitDTO.md)
 - [UpdateBusinessOfferPriceDTO](docs/UpdateBusinessOfferPriceDTO.md)
 - [UpdateBusinessPricesRequest](docs/UpdateBusinessPricesRequest.md)
 - [UpdateCampaignOfferDTO](docs/UpdateCampaignOfferDTO.md)
 - [UpdateCampaignOffersRequest](docs/UpdateCampaignOffersRequest.md)
 - [UpdateMappingDTO](docs/UpdateMappingDTO.md)
 - [UpdateMappingsOfferDTO](docs/UpdateMappingsOfferDTO.md)
 - [UpdateOfferContentRequest](docs/UpdateOfferContentRequest.md)
 - [UpdateOfferContentResponse](docs/UpdateOfferContentResponse.md)
 - [UpdateOfferContentResultDTO](docs/UpdateOfferContentResultDTO.md)
 - [UpdateOfferDTO](docs/UpdateOfferDTO.md)
 - [UpdateOfferMappingDTO](docs/UpdateOfferMappingDTO.md)
 - [UpdateOfferMappingEntryDTO](docs/UpdateOfferMappingEntryDTO.md)
 - [UpdateOfferMappingEntryRequest](docs/UpdateOfferMappingEntryRequest.md)
 - [UpdateOfferMappingsRequest](docs/UpdateOfferMappingsRequest.md)
 - [UpdateOrderItemRequest](docs/UpdateOrderItemRequest.md)
 - [UpdateOrderStatusDTO](docs/UpdateOrderStatusDTO.md)
 - [UpdateOrderStatusRequest](docs/UpdateOrderStatusRequest.md)
 - [UpdateOrderStatusResponse](docs/UpdateOrderStatusResponse.md)
 - [UpdateOrderStatusesDTO](docs/UpdateOrderStatusesDTO.md)
 - [UpdateOrderStatusesRequest](docs/UpdateOrderStatusesRequest.md)
 - [UpdateOrderStatusesResponse](docs/UpdateOrderStatusesResponse.md)
 - [UpdateOrderStorageLimitRequest](docs/UpdateOrderStorageLimitRequest.md)
 - [UpdateOutletLicenseRequest](docs/UpdateOutletLicenseRequest.md)
 - [UpdatePriceWithDiscountDTO](docs/UpdatePriceWithDiscountDTO.md)
 - [UpdatePricesRequest](docs/UpdatePricesRequest.md)
 - [UpdateStockDTO](docs/UpdateStockDTO.md)
 - [UpdateStockItemDTO](docs/UpdateStockItemDTO.md)
 - [UpdateStocksRequest](docs/UpdateStocksRequest.md)
 - [UpdateTimeDTO](docs/UpdateTimeDTO.md)
 - [ValueRestrictionDTO](docs/ValueRestrictionDTO.md)
 - [VerifyOrderEacRequest](docs/VerifyOrderEacRequest.md)
 - [VerifyOrderEacResponse](docs/VerifyOrderEacResponse.md)
 - [WarehouseAddressDTO](docs/WarehouseAddressDTO.md)
 - [WarehouseDTO](docs/WarehouseDTO.md)
 - [WarehouseGroupDTO](docs/WarehouseGroupDTO.md)
 - [WarehouseOfferDTO](docs/WarehouseOfferDTO.md)
 - [WarehouseOffersDTO](docs/WarehouseOffersDTO.md)
 - [WarehouseStockDTO](docs/WarehouseStockDTO.md)
 - [WarehouseStockType](docs/WarehouseStockType.md)
 - [WarehousesDTO](docs/WarehousesDTO.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="OAuth"></a>
### OAuth

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://oauth.yandex.ru/authorize
- **Scopes**: 
 - **market:partner-api**: API Яндекс.Маркета / Поиска по товарам для партнеров


## Author




